@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2009 the xine project
+ * Copyright (C) 2000-2017 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -32,6 +32,7 @@
 #include "config_wrapper.h"
 #include "utils.h"
 #include "globals.h"
+#include "libcommon.h" /* strsep replacement */
 
 /* 
  * experience level above this level 
@@ -41,7 +42,7 @@
 #define XINE_CONFIG_SECURITY   30
 
 
-static void config_update(xine_cfg_entry_t *entry, int type, int min, int max, int value, char *string) {
+static void config_update(xine_cfg_entry_t *entry, int type, int min, int max, int value, const char *string) {
 
   switch(type) {
 
@@ -83,7 +84,7 @@ void config_update_range(const char *key, int min, int max) {
     fprintf(stderr, "WOW, range key %s isn't registered\n", key);
 }
 
-void config_update_string(const char *key, char *string) {
+void config_update_string(const char *key, const char *string) {
   xine_cfg_entry_t entry;
 
   if((xine_config_lookup_entry(__xineui_global_xine_instance, key, &entry)) && string)
