@@ -32,12 +32,15 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
+#ifdef HAVE_SYS_UTSNAME_H
 #include <sys/utsname.h>
+#endif
 
 #include "dump.h"
 #include "globals.h"
 
 void dump_host_info(void) {
+#ifdef HAVE_SYS_UTSNAME_H
   struct utsname uts;
 
   if((uname(&uts)) == -1) {
@@ -58,22 +61,24 @@ void dump_host_info(void) {
 #endif
 #endif
   }
+#endif
 }
 
 void dump_cpu_infos(void) {
 #if defined (__linux__)
   FILE *stream;
   char  buffer[2048];
-  
+  size_t got;
+
   if((stream = fopen("/proc/cpuinfo", "r"))) {
     
     printf("   CPU information:\n");
     printf("   ---------------\n");
     
     memset(&buffer, 0, sizeof(buffer));
-    while(fread(&buffer, 1, 2047, stream)) {
+    while((got = fread(&buffer, 1, 2047, stream)) > 0) {
       char *p, *pp;
-      
+      buffer[got] = 0;
       pp = buffer;
       while((p = strsep(&pp, "\n"))) {
 	if(p && strlen(p))
