@@ -35,6 +35,7 @@
 #include <xine/xineutils.h>
 
 #include "utils.h"
+#include "libcommon.h" /* strsep replacement */
 
 extern char **environ;
 
@@ -176,7 +177,7 @@ int mkdir_safe(char *path) {
   memset(&buf, 0, sizeof(buf));
   memset(&buf2, 0, sizeof(buf2));
   
-  strcpy(buf, path);
+  strlcpy(buf, path, sizeof(buf));
   pp = buf;
   while((p = xine_strsep(&pp, "/")) != NULL) {
     if(p && strlen(p)) {
@@ -335,3 +336,42 @@ int is_a_file(char *filename) {
   
   return (S_ISREG(pstat.st_mode));
 }
+
+char *xitk_vasprintf(const char *format, va_list args)
+{
+  char *result;
+  int   size = 100;
+
+  result = malloc(size);
+  if (!result) {
+    fprintf(stderr, "xitk_vasprintf: out of memory\n");
+    return NULL;
+  }
+
+  while (1) {
+    char *tmp;
+    va_list ap;
+    int n;
+
+    va_copy(ap, args);
+    n = vsnprintf(result, size, format, ap);
+    va_end(ap);
+
+    if (n > -1 && n < size)
+      break;
+
+    if(n > -1)
+      size = n + 1;
+    else
+      size *= 2;
+
+    if((tmp = realloc(result, size)) == NULL) {
+      fprintf(stderr, "xitk_vasprintf: out of memory\n");
+      free(result);
+      return NULL;
+    }
+    result = tmp;
+  }
+
+  return result;
+}
