@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2011 the xine project
+ * Copyright (C) 2000-2017 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -38,16 +38,19 @@
 #define OVL_PALETTE_SIZE 256
 
 #ifdef	__GNUC__
-#define CLUT_Y_CR_CB_INIT(_y,_cr,_cb)	{ .y = (_y), .cr = (_cr), .cb = (_cb)}
+#define CLUT_Y_CR_CB_INIT(_y,_cr,_cb)	{{ .y = (_y), .cr = (_cr), .cb = (_cb)}}
 #else
-#define CLUT_Y_CR_CB_INIT(_y,_cr,_cb)	{ (_cb), (_cr), (_y) }
+#define CLUT_Y_CR_CB_INIT(_y,_cr,_cb)	{{ (_cb), (_cr), (_y) }}
 #endif
 
-typedef struct {         /* CLUT == Color LookUp Table */
-  uint8_t cb    : 8;
-  uint8_t cr    : 8;
-  uint8_t y     : 8;
-  uint8_t foo   : 8;
+typedef union {         /* CLUT == Color LookUp Table */
+  struct {
+    uint8_t cb    : 8;
+    uint8_t cr    : 8;
+    uint8_t y     : 8;
+    uint8_t foo   : 8;
+  } u8;
+  uint32_t u32;
 } __attribute__ ((packed)) clut_t;
 
 static const clut_t textpalettes_color[] = {
@@ -177,7 +180,7 @@ void osd_init(void) {
 			    XINE_TEXTPALETTE_WHITE_BLACK_TRANSPARENT, XINE_OSD_TEXT1);
 
   fbxine.osd.bar[0] = xine_osd_new(fbxine.stream, 0, 0, BAR_WIDTH + 1, BAR_HEIGHT + 1);
-  xine_osd_set_palette(fbxine.osd.bar[0], (uint32_t *)textpalettes_color, textpalettes_trans);
+  xine_osd_set_palette(fbxine.osd.bar[0], &textpalettes_color[0].u32, textpalettes_trans);
 
   fbxine.osd.bar[1] = xine_osd_new(fbxine.stream, 0, 0, BAR_WIDTH + 1, BAR_HEIGHT + 1);
   xine_osd_set_font(fbxine.osd.bar[1], "sans", fonth);
@@ -233,33 +236,18 @@ void osd_deinit(void) {
 }
 
 
-void osd_display_info(char *info, ...) {
+void osd_display_info(const char *info, ...) {
 
   if(fbxine.osd.enabled) {
     va_list   args;
     char     *buf;
-    int       n, size = 100;
-    
-    if((buf = malloc(size)) == NULL) 
+
+    va_start(args, info);
+    buf = xitk_vasprintf(info, args);
+    va_end(args);
+
+    if(!buf)
       return;
-    
-    while(1) {
-      
-      va_start(args, info);
-      n = vsnprintf(buf, size, info, args);
-      va_end(args);
-      
-      if(n > -1 && n < size)
-	break;
-      
-      if(n > -1)
-	size = n + 1;
-      else
-	size *= 2;
-      
-      if((buf = realloc(buf, size)) == NULL)
-	return;
-    }
 
     xine_osd_clear(fbxine.osd.info);
 
@@ -453,7 +441,7 @@ void osd_stream_infos(void) {
   }
 }
 
-void osd_draw_bar(char *title, int min, int max, int val, int type) {
+void osd_draw_bar(const char *title, int min, int max, int val, int type) {
 
   if(fbxine.osd.enabled) {
     uint32_t width, height;
@@ -586,8 +574,8 @@ void osd_stream_position(void) {
 void osd_display_spu_lang(void) {
   char   buffer[32];
   char   lang_buffer[XINE_LANG_MAX];
-  char  *lang = NULL;
   int    channel;
+  const char *lang = NULL;
   
   channel = xine_get_param(fbxine.stream, XINE_PARAM_SPU_CHANNEL);
 
@@ -615,8 +603,8 @@ void osd_display_spu_lang(void) {
 void osd_display_audio_lang(void) {
   char   buffer[32];
   char   lang_buffer[XINE_LANG_MAX];
-  char  *lang = NULL;
   int    channel;
+  const char *lang = NULL;
 
   channel = xine_get_param(fbxine.stream, XINE_PARAM_AUDIO_CHANNEL_LOGICAL);
 
