@@ -1,5 +1,6 @@
 /* 
  * Copyright (C) 2008 by Dirk Meyer
+ * Copyright (C) 2003-2017 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -25,6 +26,7 @@
 
 #include "globals.h"
 #include "utils.h"
+#include "libcommon.h"  /* strsep replacement */
 
 typedef struct {
   xine_post_t                 *post;
@@ -104,7 +106,7 @@ static post_element_t **pplugin_parse_and_load(int plugin_type, const char *pcha
     ppost_chain = post_chain;
     while((p = xine_strsep(&ppost_chain, ";"))) {
       
-      if(p && strlen(p)) {
+      if(strlen(p)) {
 	char          *plugin, *args = NULL;
 	xine_post_t   *post;
 	
@@ -160,7 +162,7 @@ static post_element_t **pplugin_parse_and_load(int plugin_type, const char *pcha
 		while((*p != '\0') && (*p != '='))
 		  p++;
 		
-		if(p && strlen(p)) {
+		if(strlen(p)) {
 		  int param_num = 0;
 		  
 		  *p++ = '\0';
@@ -279,13 +281,13 @@ static void pplugin_parse_and_store_post(int plugin_type, const char *post_chain
       (*_post_elements)[i] = NULL;
       (*_post_elements_num) += num;
 
+      free(posts);
     }
     else {
       *_post_elements     = posts;
       *_post_elements_num = num;
     }
   }
-  
 }
 
 
