@@ -13,18 +13,15 @@
 /*
  *      Split the ID - damages input
  */
-static char *_SplitID(char *file) {
+static void _SplitID(char *file) {
 #ifndef __EMX__
   char *p = strrchr(file, ':');
 #else
   char *p = strrchr(file, ';');
 #endif
-  
-  if (p == NULL)
-    return "";
-  else {
+ 
+  if (p) {
     *p++ = 0;
-    return p;
   }
 }
 
@@ -81,6 +78,7 @@ static unsigned char *_LoadPNG(ImlibData * id, FILE * f, int *w, int *h, int *t)
 
   if (lines == NULL || *w > INT_MAX / 4)
     {
+      free(lines);
       free(data);
       png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
       return NULL;
@@ -224,8 +222,12 @@ static unsigned char *_LoadJPEG(ImlibData * id, FILE * f, int *w, int *h) {
 
 int ispng(FILE *f) {
   unsigned char       buf[8];
-  
-  if (!f || fread (buf, 1, sizeof (buf), f) < sizeof (buf))
+
+  if (!f) {
+    return 0;
+  }
+
+  if (fread (buf, 1, sizeof (buf), f) < sizeof (buf))
   {
     rewind (f);
     return 0;
@@ -237,7 +239,11 @@ int ispng(FILE *f) {
 static int isjpeg(FILE *f) {
   unsigned char       buf[4];
 
-  if (!f || fread (buf, 1, sizeof (buf), f) < sizeof (buf))
+  if (!f) {
+    return 0;
+  }
+
+  if (fread (buf, 1, sizeof (buf), f) < sizeof (buf))
   {
     rewind (f);
     return 0;
@@ -246,7 +252,7 @@ static int isjpeg(FILE *f) {
   return buf[0] == 0xFF && buf[1] == 0xD8 && buf[2] == 0xFF && buf[3] == 0xE0;
 }
 
-ImlibImage * Imlib_load_image(ImlibData * id, char *file) {
+ImlibImage * Imlib_load_image(ImlibData * id, const char *file) {
   int                 w, h;
   unsigned char      *data = NULL;
   ImlibImage         *im;
@@ -259,9 +265,6 @@ ImlibImage * Imlib_load_image(ImlibData * id, char *file) {
   }                   fmt = FORMAT_UNKNOWN;
   int                 trans;
 
-  fmt = 0;
-  data = NULL;
-
   if (!file)
     return NULL;
   if (id->cache.on_image)
@@ -292,19 +295,19 @@ ImlibImage * Imlib_load_image(ImlibData * id, char *file) {
     fmt = FORMAT_JPEG;
 
   trans = 0;
-  if (!data) {
-      switch (fmt)
-	{
-	case FORMAT_PNG:
-	    data = _LoadPNG(id, p, &w, &h, &trans);
-	  break;
-	case FORMAT_JPEG:
-	    data = _LoadJPEG(id, p, &w, &h);
-	  break;
-	default:
-	  break;
-	}
-    }
+
+  switch (fmt)
+  {
+    case FORMAT_PNG:
+        data = _LoadPNG(id, p, &w, &h, &trans);
+        break;
+    case FORMAT_JPEG:
+        data = _LoadJPEG(id, p, &w, &h);
+        break;
+    default:
+        break;
+  }
+
   if (p) {
     if (p != stdin) 
       fclose(p);
