@@ -76,7 +76,7 @@ Imlib_init(Display * disp)
   ImlibData          *id;
   XWindowAttributes   xwa;
   XVisualInfo         xvi, *xvir;
-  char               *s, *s1, *s2;
+  char               *s, *s1;
   FILE               *f;
   int                 override = 0;
   int                 dither = 0;
@@ -208,6 +208,8 @@ Imlib_init(Display * disp)
       s = NULL;
       while (getline (&s, &length, f) >= 0)
 	{
+          const char *s2;
+
 	  if (s[0] == '#')
 	    continue;
 
@@ -224,6 +226,7 @@ Imlib_init(Display * disp)
 
 	  if (!strcasecmp("PaletteFile", s1))
 	    {
+              free(palfile);
 	      palfile = strdup(s2);
 	    }
 	  else if (!strcasecmp("PaletteOverride", s1))
@@ -301,8 +304,9 @@ Imlib_init(Display * disp)
 	    }
 	  else if (!strcasecmp("ForceVisualID", s1))
 	    {
-	      sscanf(s, "%1024s %x", s1, &num);
-	      vis = num;
+              unsigned int u;
+              sscanf(s, "%1024s %x", s1, &u);
+              vis = u;
 	    }
 	  else if (!strcasecmp("Fallback", s1))
 	    {
@@ -630,7 +634,7 @@ Imlib_init_with_params(Display * disp, ImlibInitParams * p)
   ImlibData          *id;
   XWindowAttributes   xwa;
   XVisualInfo         xvi, *xvir;
-  char               *s, *s1, *s2;
+  char               *s, *s1;
   FILE               *f;
   int                 override = 0;
   int                 dither = 0;
@@ -732,7 +736,7 @@ Imlib_init_with_params(Display * disp, ImlibInitParams * p)
   else
     id->x.root_cmap = 0;
   id->num_colors = 0;
-  asprintf(&s, "%s/.imrc", getenv("HOME"));
+  asprintf(&s, "%s/.imrc", xine_get_homedir ());
 
   old_locale = strdup(setlocale(LC_NUMERIC, NULL));
   setlocale(LC_NUMERIC, "C");
@@ -760,6 +764,8 @@ Imlib_init_with_params(Display * disp, ImlibInitParams * p)
       s = NULL;
       while (getline (&s, &length, f) >= 0)
 	{
+          const char *s2;
+
 	  if (s[0] == '#')
 	    continue;
 
@@ -776,6 +782,7 @@ Imlib_init_with_params(Display * disp, ImlibInitParams * p)
 
 	  if (!strcasecmp("PaletteFile", s1))
 	    {
+              free(palfile);
 	      palfile = strdup(s2);
 	    }
 	  else if (!strcasecmp("PaletteOverride", s1))
@@ -853,8 +860,9 @@ Imlib_init_with_params(Display * disp, ImlibInitParams * p)
 	    }
 	  else if (!strcasecmp("ForceVisualID", s1))
 	    {
-	      sscanf(s, "%1024s %x", s1, &num);
-	      vis = num;
+              unsigned int u;
+              sscanf(s, "%1024s %x", s1, &u);
+              vis = u;
 	    }
 	  else if (!strcasecmp("Fallback", s1))
 	    {
@@ -1300,8 +1308,8 @@ Imlib_kill_image(ImlibData * id, ImlibImage * im)
     {
       if (id->cache.on_image)
 	{
-	  free_image(id, im);
 	  flush_image(id, im);
+	  free_image(id, im);
 	  clean_caches(id);
 	}
       else
