@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2009 the xine project
+ * Copyright (C) 2000-2017 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -81,48 +81,29 @@ static void errors_create_window(char *title, char *message) {
 /*
  * Display an error window.
  */
-void xine_error(char *message, ...) {
+void xine_error(const char *message, ...) {
   va_list   args;
   char     *buf;
-  int       n, size = 100;
-  
-  if((buf = xitk_xmalloc(size)) == NULL) 
+
+  va_start(args, message);
+  buf = xitk_vasprintf(message, args);
+  va_end(args);
+
+  if (!buf)
     return;
-  
-  while(1) {
-    
-    va_start(args, message);
-    n = vsnprintf(buf, size, message, args);
-    va_end(args);
-    
-    if(n > -1 && n < size)
-      break;
-    
-    if(n > -1)
-      size = n + 1;
-    else
-      size *= 2;
-    
-    if((buf = realloc(buf, size)) == NULL)
-      return;
-  }
-  
+
   if(gGui->stdctl_enable || !gGui->display) {
     printf("%s\n", buf);
   }
   else {
-    char buf2[(strlen(buf) * 2) + 1];
-    
     dump_error(buf);
 
-    xitk_subst_special_chars(buf, buf2);
-
     if( gGui->nongui_error_msg ) {
-      gGui->nongui_error_msg( buf2 );
+      gGui->nongui_error_msg( buf );
     } else {
       xitk_window_t *xw;
 
-      xw = xitk_window_dialog_error(gGui->imlib_data, "%s", buf2);
+      xw = xitk_window_dialog_error(gGui->imlib_data, "%s", buf);
 
       if(!gGui->use_root_window && gGui->video_display == gGui->display) {
         XLockDisplay(gGui->display);
@@ -139,43 +120,24 @@ void xine_error(char *message, ...) {
 /*
  * Display an error window, with more button.
  */
-void xine_error_with_more(char *message, ...) {
+void xine_error_with_more(const char *message, ...) {
   va_list   args;
   char     *buf;
-  int       n, size = 100;
-  
-  if((buf = xitk_xmalloc(size)) == NULL) 
+
+  va_start(args, message);
+  buf = xitk_vasprintf(message, args);
+  va_end(args);
+
+  if (!buf)
     return;
-  
-  while(1) {
-    
-    va_start(args, message);
-    n = vsnprintf(buf, size, message, args);
-    va_end(args);
-    
-    if(n > -1 && n < size)
-      break;
-    
-    if(n > -1)
-      size = n + 1;
-    else
-      size *= 2;
-    
-    if((buf = realloc(buf, size)) == NULL)
-      return;
-  }
-  
+
   dump_error(buf);
 
   if(gGui->stdctl_enable) {
     printf("%s\n", buf);
   }
   else {
-    char buf2[(strlen(buf) * 2) + 1];
-
-    xitk_subst_special_chars(buf, buf2);
-
-    errors_create_window(_("Error"), buf2);
+    errors_create_window(_("Error"), buf);
   }
   
   free(buf);
@@ -184,48 +146,29 @@ void xine_error_with_more(char *message, ...) {
 /*
  * Display an informative window.
  */
-void xine_info(char *message, ...) {
+void xine_info(const char *message, ...) {
   va_list   args;
   char     *buf;
-  int       n, size = 100;
-  
-  if((buf = xitk_xmalloc(size)) == NULL) 
+
+  va_start(args, message);
+  buf = xitk_vasprintf(message, args);
+  va_end(args);
+
+  if (!buf)
     return;
-  
-  while(1) {
-    
-    va_start(args, message);
-    n = vsnprintf(buf, size, message, args);
-    va_end(args);
-    
-    if(n > -1 && n < size)
-      break;
-    
-    if(n > -1)
-      size = n + 1;
-    else
-      size *= 2;
-    
-    if((buf = realloc(buf, size)) == NULL)
-      return;
-  }
-  
+
   dump_info(buf);
 
   if(gGui->stdctl_enable) {
     printf("%s\n", buf);
   }
   else {
-    char           buf2[(strlen(buf) * 2) + 1];
-
-    xitk_subst_special_chars(buf, buf2);
-
     if( gGui->nongui_error_msg ) {
-      gGui->nongui_error_msg( buf2 );
+      gGui->nongui_error_msg( buf );
     } else {
       xitk_window_t *xw;
 
-      xw = xitk_window_dialog_info(gGui->imlib_data, "%s", buf2);
+      xw = xitk_window_dialog_info(gGui->imlib_data, "%s", buf);
 
       if(!gGui->use_root_window && gGui->video_display == gGui->display) {
         XLockDisplay(gGui->display);
@@ -242,9 +185,9 @@ void xine_info(char *message, ...) {
 /*
  * Display an error window error from a xine engine error.
  */
-void gui_handle_xine_error(xine_stream_t *stream, char *mrl) {
+void gui_handle_xine_error(xine_stream_t *stream, const char *mrl) {
   int   err;
-  char *_mrl = mrl;
+  const char *_mrl = mrl;
 
   if(_mrl == NULL)
     _mrl = (stream == gGui->stream) ? gGui->mmk.mrl : gGui->visual_anim.mrls[gGui->visual_anim.current];
