@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2014 the xine project
+ * Copyright (C) 2000-2017 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -78,11 +78,6 @@ typedef struct {
 
 static _eventer_t    *eventer = NULL;
 
-/* Initialized below */
-static char *menu_items_default[8] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL };
-static char *menu_items_dvd[8] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL };
-static char *menu_items_bd[8] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL };
-
 void event_sender_sticky_cb(void *data, xine_cfg_entry_t *cfg) {
   int old_sticky_value = gGui->eventer_sticky;
   
@@ -124,77 +119,37 @@ void event_sender_update_tips_timeout(unsigned long timeout) {
 }
 
 /* Send given event to xine engine */
-void event_sender_send(int event) {
+void event_sender_send (int event) {
+  xine_event_t   xine_event;
+
+  if (!event)
+    return;
+
+  xine_event.type        = event;
+  xine_event.data_length = 0;
+  xine_event.data        = NULL;
+  xine_event.stream      = gGui->stream;
+  gettimeofday(&xine_event.tv, NULL);
+  xine_event_send (gGui->stream, &xine_event);
+}
+
+static void event_sender_send2 (xitk_widget_t *w, void *data) {
+  int event = (long int)data;
   xine_event_t   xine_event;
 
   xine_event.type        = event;
-  
-  if(xine_event.type != 0) {
-    xine_event.data_length = 0;
-    xine_event.data        = NULL;
-    xine_event.stream      = gGui->stream;
-    gettimeofday(&xine_event.tv, NULL);
-
-    xine_event_send(gGui->stream, &xine_event);
-  }
-}
-
-static void event_sender_up(xitk_widget_t *w, void *data) {
-  event_sender_send(XINE_EVENT_INPUT_UP);
-}
-
-static void event_sender_down(xitk_widget_t *w, void *data) {
-  event_sender_send(XINE_EVENT_INPUT_DOWN);
-}
-
-static void event_sender_left(xitk_widget_t *w, void *data) {
-  event_sender_send(XINE_EVENT_INPUT_LEFT);
-}
-
-static void event_sender_right(xitk_widget_t *w, void *data) {
-  event_sender_send(XINE_EVENT_INPUT_RIGHT);
-}
-
-static void event_sender_select(xitk_widget_t *w, void *data) {
-  event_sender_send(XINE_EVENT_INPUT_SELECT);
-}
-
-static void event_sender_menu(xitk_widget_t *w, void *data) {
-  int event = (int)(intptr_t) data;
-  int events[7] = {
-    XINE_EVENT_INPUT_MENU1, XINE_EVENT_INPUT_MENU2, XINE_EVENT_INPUT_MENU3,
-    XINE_EVENT_INPUT_MENU4, XINE_EVENT_INPUT_MENU5, XINE_EVENT_INPUT_MENU6,
-    XINE_EVENT_INPUT_MENU7
-  };
-
-  event_sender_send(events[event]);
-}
-
-static void event_sender_num(xitk_widget_t *w, void *data) {
-  int event = (int)(intptr_t) data;
-  int events[11] = { 
-    XINE_EVENT_INPUT_NUMBER_0, XINE_EVENT_INPUT_NUMBER_1, XINE_EVENT_INPUT_NUMBER_2,
-    XINE_EVENT_INPUT_NUMBER_3, XINE_EVENT_INPUT_NUMBER_4, XINE_EVENT_INPUT_NUMBER_5,
-    XINE_EVENT_INPUT_NUMBER_6, XINE_EVENT_INPUT_NUMBER_7, XINE_EVENT_INPUT_NUMBER_8,
-    XINE_EVENT_INPUT_NUMBER_9, XINE_EVENT_INPUT_NUMBER_10_ADD
-  };
-
-  event_sender_send(events[event]);
-}
-
-static void event_sender_angle(xitk_widget_t *w, void *data) {
-  int event = (int)(intptr_t) data;
-  int events[11] = { 
-    XINE_EVENT_INPUT_ANGLE_NEXT, XINE_EVENT_INPUT_ANGLE_PREVIOUS
-  };
-
-  event_sender_send(events[event]);
+  xine_event.data_length = 0;
+  xine_event.data        = NULL;
+  xine_event.stream      = gGui->stream;
+  gettimeofday(&xine_event.tv, NULL);
+  xine_event_send (gGui->stream, &xine_event);
 }
 
 static void event_sender_exit(xitk_widget_t *, void *);
 
 static void event_sender_handle_event(XEvent *event, void *data) {
-  
+  xine_event_t  xine_event;
+
   switch(event->type) {
 
   case ButtonRelease:
@@ -209,7 +164,7 @@ static void event_sender_handle_event(XEvent *event, void *data) {
 	  xitk_window_move_window(gGui->imlib_data, eventer->xwin, eventer->x, eventer->y);
       }
     }
-    break;
+    return;
 
   case KeyPress:
     {
@@ -225,87 +180,111 @@ static void event_sender_handle_event(XEvent *event, void *data) {
 
       switch(key) {
       case XK_Up:
-	event_sender_up(NULL, NULL);
+        xine_event.type = XINE_EVENT_INPUT_UP;
 	break;
       case XK_Down:
-	event_sender_down(NULL, NULL);
+        xine_event.type = XINE_EVENT_INPUT_DOWN;
 	break;
       case XK_Left:
-	event_sender_left(NULL, NULL);
+        xine_event.type = XINE_EVENT_INPUT_LEFT;
 	break;
       case XK_Right:
-	event_sender_right(NULL, NULL);
+        xine_event.type = XINE_EVENT_INPUT_RIGHT;
 	break;
 
       case XK_Return:
       case XK_KP_Enter:
       case XK_ISO_Enter:
-	event_sender_select(NULL, NULL);
+        xine_event.type = XINE_EVENT_INPUT_SELECT;
 	break;
 	
       case XK_0:
-	event_sender_num(NULL, (void *)0);
+        xine_event.type = XINE_EVENT_INPUT_NUMBER_0;
 	break;
       case XK_1:
-	event_sender_num(NULL, (void *)1);
+        xine_event.type = XINE_EVENT_INPUT_NUMBER_1;
 	break;
       case XK_2:
-	event_sender_num(NULL, (void *)2);
+        xine_event.type = XINE_EVENT_INPUT_NUMBER_2;
 	break;
       case XK_3:
-	event_sender_num(NULL, (void *)3);
+        xine_event.type = XINE_EVENT_INPUT_NUMBER_3;
 	break;
       case XK_4:
-	event_sender_num(NULL, (void *)4);
+        xine_event.type = XINE_EVENT_INPUT_NUMBER_4;
 	break;
       case XK_5:
-	event_sender_num(NULL, (void *)5);
+        xine_event.type = XINE_EVENT_INPUT_NUMBER_5;
 	break;
       case XK_6:
-	event_sender_num(NULL, (void *)6);
+        xine_event.type = XINE_EVENT_INPUT_NUMBER_6;
 	break;
       case XK_7:
-	event_sender_num(NULL, (void *)7);
+        xine_event.type = XINE_EVENT_INPUT_NUMBER_7;
 	break;
       case XK_8:
-	event_sender_num(NULL, (void *)8);
+        xine_event.type = XINE_EVENT_INPUT_NUMBER_8;
 	break;
       case XK_9:
-	event_sender_num(NULL, (void *)9);
+        xine_event.type = XINE_EVENT_INPUT_NUMBER_9;
 	break;
 
       case XK_plus:
       case XK_KP_Add:
-	event_sender_num(NULL, (void *)10);
+        xine_event.type = XINE_EVENT_INPUT_NUMBER_10_ADD;
 	break;
 
       case XK_Escape:
 	event_sender_exit(NULL, NULL);
-	break;
+	return;
 
       default:
 	gui_handle_event(event, data);
-	break;
+	return;
       }
     }
     break;
+
+    default:
+      return;
   }
+
+  xine_event.data_length = 0;
+  xine_event.data        = NULL;
+  xine_event.stream      = gGui->stream;
+  gettimeofday(&xine_event.tv, NULL);
+  xine_event_send (gGui->stream, &xine_event);
 }
 
 void event_sender_update_menu_buttons(void) {
 
   if(eventer) {
-    int i;
-    char **lbls = menu_items_default;
-    
-    if((!strncmp(gGui->mmk.mrl, "dvd:/", 5)) || (!strncmp(gGui->mmk.mrl, "dvdnav:/", 8)))
-      lbls = menu_items_dvd;
-    if(!strncmp(gGui->mmk.mrl, "bd:/", 4))
-      lbls = menu_items_bd;
-    
-    for(i = 0; i < 7; i++)
-      xitk_labelbutton_change_label(eventer->menus.menu[i], lbls[i]);
-
+    if((!strncmp(gGui->mmk.mrl, "dvd:/", 5)) || (!strncmp(gGui->mmk.mrl, "dvdnav:/", 8))) {
+      xitk_labelbutton_change_label(eventer->menus.menu[0], _("Menu toggle"));
+      xitk_labelbutton_change_label(eventer->menus.menu[1], _("Title"));
+      xitk_labelbutton_change_label(eventer->menus.menu[2], _("Root"));
+      xitk_labelbutton_change_label(eventer->menus.menu[3], _("Subpicture"));
+      xitk_labelbutton_change_label(eventer->menus.menu[4], _("Audio"));
+      xitk_labelbutton_change_label(eventer->menus.menu[5], _("Angle"));
+      xitk_labelbutton_change_label(eventer->menus.menu[6], _("Part"));
+    }
+    else if(!strncmp(gGui->mmk.mrl, "bd:/", 4)) {
+      xitk_labelbutton_change_label(eventer->menus.menu[0], _("Top Menu"));
+      xitk_labelbutton_change_label(eventer->menus.menu[1], _("Popup Menu"));
+      xitk_labelbutton_change_label(eventer->menus.menu[2], _("Menu 3"));
+      xitk_labelbutton_change_label(eventer->menus.menu[3], _("Menu 4"));
+      xitk_labelbutton_change_label(eventer->menus.menu[4], _("Menu 5"));
+      xitk_labelbutton_change_label(eventer->menus.menu[5], _("Menu 6"));
+      xitk_labelbutton_change_label(eventer->menus.menu[6], _("Menu 7"));
+    } else {
+      xitk_labelbutton_change_label(eventer->menus.menu[0], _("Menu 1"));
+      xitk_labelbutton_change_label(eventer->menus.menu[1], _("Menu 2"));
+      xitk_labelbutton_change_label(eventer->menus.menu[2], _("Menu 3"));
+      xitk_labelbutton_change_label(eventer->menus.menu[3], _("Menu 4"));
+      xitk_labelbutton_change_label(eventer->menus.menu[4], _("Menu 5"));
+      xitk_labelbutton_change_label(eventer->menus.menu[5], _("Menu 6"));
+      xitk_labelbutton_change_label(eventer->menus.menu[6], _("Menu 7"));
+    }
   }
 }
 
@@ -446,16 +425,19 @@ void event_sender_panel(void) {
 
   XITK_WIDGET_INIT(&lb, gGui->imlib_data);
 
+  lb.button_type       = CLICK_BUTTON;
+  lb.align             = ALIGN_CENTER;
+  lb.callback          = event_sender_send2;
+  lb.state_callback    = NULL;
+  lb.skin_element_name = NULL;
+
+#define I2PTR(n) (void *)((long int)(n))
+
   x = 80 + 5 + 5;
   y = 5 + 23 * 3 + 5 - 40;
 
-  lb.button_type       = CLICK_BUTTON;
   lb.label             = _("Up");
-  lb.align             = ALIGN_CENTER;
-  lb.callback          = event_sender_up; 
-  lb.state_callback    = NULL;
-  lb.userdata          = NULL;
-  lb.skin_element_name = NULL;
+  lb.userdata          = I2PTR (XINE_EVENT_INPUT_UP);
   xitk_list_append_content((XITK_WIDGET_LIST_LIST(eventer->widget_list)),
 	   (eventer->navigator.up = 
 	    xitk_noskin_labelbutton_create(eventer->widget_list, 
@@ -467,13 +449,8 @@ void event_sender_panel(void) {
   x -= 70;
   y += 40;
 
-  lb.button_type       = CLICK_BUTTON;
   lb.label             = _("Left");
-  lb.align             = ALIGN_CENTER;
-  lb.callback          = event_sender_left; 
-  lb.state_callback    = NULL;
-  lb.userdata          = NULL;
-  lb.skin_element_name = NULL;
+  lb.userdata          = I2PTR (XINE_EVENT_INPUT_LEFT);
   xitk_list_append_content((XITK_WIDGET_LIST_LIST(eventer->widget_list)), 
 	   (eventer->navigator.left = 
 	    xitk_noskin_labelbutton_create(eventer->widget_list, 
@@ -485,13 +462,8 @@ void event_sender_panel(void) {
   x += 75;
   y += 5;
 
-  lb.button_type       = CLICK_BUTTON;
   lb.label             = _("Select");
-  lb.align             = ALIGN_CENTER;
-  lb.callback          = event_sender_select; 
-  lb.state_callback    = NULL;
-  lb.userdata          = NULL;
-  lb.skin_element_name = NULL;
+  lb.userdata          = I2PTR (XINE_EVENT_INPUT_SELECT);
   xitk_list_append_content((XITK_WIDGET_LIST_LIST(eventer->widget_list)), 
 	   (eventer->navigator.select = 
 	    xitk_noskin_labelbutton_create(eventer->widget_list, 
@@ -503,13 +475,8 @@ void event_sender_panel(void) {
   x += 65;
   y -= 5;
 
-  lb.button_type       = CLICK_BUTTON;
   lb.label             = _("Right");
-  lb.align             = ALIGN_CENTER;
-  lb.callback          = event_sender_right; 
-  lb.state_callback    = NULL;
-  lb.userdata          = NULL;
-  lb.skin_element_name = NULL;
+  lb.userdata          = I2PTR (XINE_EVENT_INPUT_RIGHT);
   xitk_list_append_content((XITK_WIDGET_LIST_LIST(eventer->widget_list)), 
 	   (eventer->navigator.right = 
 	    xitk_noskin_labelbutton_create(eventer->widget_list, 
@@ -521,13 +488,8 @@ void event_sender_panel(void) {
   x -= 70;
   y += 40;
  
-  lb.button_type       = CLICK_BUTTON;
   lb.label             = _("Down");
-  lb.align             = ALIGN_CENTER;
-  lb.callback          = event_sender_down; 
-  lb.state_callback    = NULL;
-  lb.userdata          = NULL;
-  lb.skin_element_name = NULL;
+  lb.userdata          = I2PTR (XINE_EVENT_INPUT_DOWN);
   xitk_list_append_content((XITK_WIDGET_LIST_LIST(eventer->widget_list)), 
 	   (eventer->navigator.down = 
 	    xitk_noskin_labelbutton_create(eventer->widget_list, 
@@ -544,13 +506,8 @@ void event_sender_panel(void) {
     
     snprintf(number, sizeof(number), "%d", i);
 
-    lb.button_type       = CLICK_BUTTON;
     lb.label             = number;
-    lb.align             = ALIGN_CENTER;
-    lb.callback          = event_sender_num;
-    lb.state_callback    = NULL;
-    lb.userdata          = (void *)(intptr_t)i;
-    lb.skin_element_name = NULL;
+    lb.userdata          = I2PTR (XINE_EVENT_INPUT_NUMBER_0 + i);
 
     if(!i)
       x -= 46;
@@ -580,13 +537,8 @@ void event_sender_panel(void) {
     
     snprintf(number, sizeof(number), "+ %d", i);
     
-    lb.button_type       = CLICK_BUTTON;
     lb.label             = number;
-    lb.align             = ALIGN_CENTER;
-    lb.callback          = event_sender_num;
-    lb.state_callback    = NULL;
-    lb.userdata          = (void *)(intptr_t)i;
-    lb.skin_element_name = NULL;
+    lb.userdata          = I2PTR (XINE_EVENT_INPUT_NUMBER_10_ADD);
     
     xitk_list_append_content((XITK_WIDGET_LIST_LIST(eventer->widget_list)), 
 	     (eventer->numbers.number[i] = 
@@ -599,13 +551,8 @@ void event_sender_panel(void) {
   x = WINDOW_WIDTH - 80 - 5;
   y = 5 + 23 * 3 + 5 + 40 + 5;
 
-  lb.button_type       = CLICK_BUTTON;
   lb.label             = _("Angle +");
-  lb.align             = ALIGN_CENTER;
-  lb.callback          = event_sender_angle; 
-  lb.state_callback    = NULL;
-  lb.userdata          = (void *)1;
-  lb.skin_element_name = NULL;
+  lb.userdata          = I2PTR (XINE_EVENT_INPUT_ANGLE_NEXT);
   xitk_list_append_content((XITK_WIDGET_LIST_LIST(eventer->widget_list)), 
 	   (eventer->angles.next = 
 	    xitk_noskin_labelbutton_create(eventer->widget_list, 
@@ -615,13 +562,8 @@ void event_sender_panel(void) {
 
   y += 23;
 
-  lb.button_type       = CLICK_BUTTON;
   lb.label             = _("Angle -");
-  lb.align             = ALIGN_CENTER;
-  lb.callback          = event_sender_angle; 
-  lb.state_callback    = NULL;
-  lb.userdata          = (void *)0;
-  lb.skin_element_name = NULL;
+  lb.userdata          = I2PTR (XINE_EVENT_INPUT_ANGLE_PREVIOUS);
   xitk_list_append_content((XITK_WIDGET_LIST_LIST(eventer->widget_list)), 
 	   (eventer->angles.prev = 
 	    xitk_noskin_labelbutton_create(eventer->widget_list, 
@@ -630,42 +572,12 @@ void event_sender_panel(void) {
   xitk_enable_and_show_widget(eventer->angles.prev);
 
 
-  /* Initialize menu labels */
-  menu_items_default[0] = _("Menu 1");
-  menu_items_default[1] = _("Menu 2");
-  menu_items_default[2] = _("Menu 3");
-  menu_items_default[3] = _("Menu 4");
-  menu_items_default[4] = _("Menu 5");
-  menu_items_default[5] = _("Menu 6");
-  menu_items_default[6] = _("Menu 7");
- 
-  menu_items_dvd[0]     = _("Menu toggle");
-  menu_items_dvd[1]     = _("Title");
-  menu_items_dvd[2]     = _("Root");
-  menu_items_dvd[3]     = _("Subpicture");
-  menu_items_dvd[4]     = _("Audio");
-  menu_items_dvd[5]     = _("Angle");
-  menu_items_dvd[6]     = _("Part");
-
-  menu_items_bd[0] = _("Top Menu");
-  menu_items_bd[1] = _("Popup Menu");
-  menu_items_bd[2] = _("Menu 3");
-  menu_items_bd[3] = _("Menu 4");
-  menu_items_bd[4] = _("Menu 5");
-  menu_items_bd[5] = _("Menu 6");
-  menu_items_bd[6] = _("Menu 7");
-
   x = 5;
   y = 5;
 
   for(i = 0; i < 7; i++) {
-    lb.button_type       = CLICK_BUTTON;
     lb.label             = "";
-    lb.align             = ALIGN_CENTER;
-    lb.callback          = event_sender_menu; 
-    lb.state_callback    = NULL;
-    lb.userdata          = (void *)(intptr_t)i;
-    lb.skin_element_name = NULL;
+    lb.userdata          = I2PTR (XINE_EVENT_INPUT_MENU1 + i);
     xitk_list_append_content((XITK_WIDGET_LIST_LIST(eventer->widget_list)), 
 	     (eventer->menus.menu[i] = 
 	      xitk_noskin_labelbutton_create(eventer->widget_list, 
@@ -689,13 +601,9 @@ void event_sender_panel(void) {
   x = WINDOW_WIDTH - 70 - 5;
   y = WINDOW_HEIGHT - 23 - 5;
 
-  lb.button_type       = CLICK_BUTTON;
   lb.label             = _("Close");
-  lb.align             = ALIGN_CENTER;
-  lb.callback          = event_sender_exit; 
-  lb.state_callback    = NULL;
+  lb.callback          = event_sender_exit;
   lb.userdata          = NULL;
-  lb.skin_element_name = NULL;
   xitk_list_append_content((XITK_WIDGET_LIST_LIST(eventer->widget_list)), 
    (w = xitk_noskin_labelbutton_create(eventer->widget_list, 
 				       &lb, x, y, 70, 23,
