@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2011 the xine project
+ * Copyright (C) 2000-2014 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -376,7 +376,7 @@ static void fb_create_input_window(char *title, char *text,
 
   {
     char buffer[256];
-    snprintf(buffer, sizeof(buffer), "filenameed%d", (unsigned int) time(NULL));
+    snprintf(buffer, sizeof(buffer), "filenameed%u", (unsigned int) time(NULL));
     
     fne->widget_key = xitk_register_event_handler(buffer, 
 						  (xitk_window_get_window(fne->xwin)),
@@ -423,7 +423,7 @@ static int is_file_match_to_filter(filebrowser_t *fb, char *file) {
       sprintf(ext, "%s ", ending);
 
       p = ext;
-      while(*p && (*p != '\0')) {
+      while(*p) {
 	*p = tolower(*p);
 	p++;
       }
@@ -599,10 +599,10 @@ static void sort_files(filebrowser_t *fb) {
   if(fb->files_num) {
     int i;
     
-    if(fb->files_sort_direction == DEFAULT_SORT)
-      func = _sortfiles_default;
-    else if(fb->files_sort_direction == REVERSE_SORT)
+    if(fb->files_sort_direction == REVERSE_SORT)
       func = _sortfiles_reverse;
+    else /*if(fb->files_sort_direction == DEFAULT_SORT)*/
+      func = _sortfiles_default;
     
     qsort(fb->norm_files, fb->files_num, sizeof(fileinfo_t), func);
     
@@ -632,10 +632,10 @@ static void sort_directories(filebrowser_t *fb) {
   if(fb->directories_num) {
     int i;
     
-    if(fb->directories_sort_direction == DEFAULT_SORT)
-      func = _sortfiles_default;
-    else if(fb->directories_sort_direction == REVERSE_SORT)
+    if(fb->directories_sort_direction == REVERSE_SORT)
       func = _sortfiles_reverse;
+    else /*if(fb->directories_sort_direction == DEFAULT_SORT)*/
+      func = _sortfiles_default;
     
     qsort(fb->dir_files, fb->directories_num, sizeof(fileinfo_t), func);
     
@@ -1617,7 +1617,7 @@ filebrowser_t *create_filebrowser(char *window_title, char *filepathname, hidden
 
   {
     char buffer[256];
-    snprintf(buffer, sizeof(buffer), "filebrowser%d", (unsigned int) time(NULL));
+    snprintf(buffer, sizeof(buffer), "filebrowser%u", (unsigned int) time(NULL));
     fb->widget_key = xitk_register_event_handler(buffer, 
 						 (xitk_window_get_window(fb->xwin)),
 						 fb_handle_events,
