@@ -240,8 +240,8 @@ static xitk_mrlbrowser_filter_t **mrl_browser_get_valid_mrl_ending(void) {
 void mrl_browser(xitk_mrl_callback_t add_cb, xitk_mrl_callback_t play_cb,
 		 select_cb_t sel_cb, xitk_dnd_callback_t dnd_cb) {
   xitk_mrlbrowser_widget_t     mb;
-  const char *const           *ip_availables = xine_get_browsable_input_plugin_ids(__xineui_global_xine_instance);
-  xitk_mrlbrowser_filter_t   **mrl_filters = mrl_browser_get_valid_mrl_ending();
+  const char *const           *ip_availables;
+  xitk_mrlbrowser_filter_t   **mrl_filters;
 
   if(mrlb != NULL) {
     show_mrl_browser();
@@ -249,6 +249,9 @@ void mrl_browser(xitk_mrl_callback_t add_cb, xitk_mrl_callback_t play_cb,
     return;
   }
 
+  ip_availables = xine_get_browsable_input_plugin_ids(__xineui_global_xine_instance);
+  mrl_filters = mrl_browser_get_valid_mrl_ending();
+
   XITK_WIDGET_INIT(&mb, gGui->imlib_data);
 
   mb.window_trans                   = (gGui->use_root_window || gGui->video_display != gGui->display) ? None : gGui->video_window;
