@@ -1,6 +1,6 @@
 #warning IMPLEMENT POST SUPPORT
 /*
- * Copyright (C) 2000-2011 the xine project
+ * Copyright (C) 2000-2017 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -140,8 +140,15 @@ struct session_commands_s {
   client_func_t   function;
 };
 
+typedef struct client_commands_s {
+  const char     *command;
+  int             origin;
+  int             enable;
+  client_func_t   function;
+} client_commands_t;
+
 static session_t             session;
-static session_commands_t    client_commands[] = {
+static const client_commands_t client_commands[] = {
   { "?",           ORIGIN_CLIENT,   1, client_help    },
   { "version",     ORIGIN_CLIENT,   1, client_version },
   { "open",        ORIGIN_CLIENT,   1, client_open    },
@@ -162,31 +169,31 @@ static session_commands_t  **session_commands = NULL;
 typedef struct commands_s commands_t;
 typedef struct client_info_s client_info_t;
 typedef struct passwds_s passwds_t;
-typedef void (*cmd_func_t)(commands_t *, client_info_t *);
+typedef void (*cmd_func_t)(const commands_t *, client_info_t *);
 
 static passwds_t   **passwds = NULL;
 
-static void do_commands(commands_t *, client_info_t *);
-static void do_help(commands_t *, client_info_t *);
-static void do_syntax(commands_t *, client_info_t *);
-static void do_auth(commands_t *, client_info_t *);
-static void do_mrl(commands_t *, client_info_t *);
-static void do_playlist(commands_t *, client_info_t *);
-static void do_play(commands_t *, client_info_t *);
-static void do_stop(commands_t *, client_info_t *);
-static void do_pause(commands_t *, client_info_t *);
-static void do_exit(commands_t *, client_info_t *);
-static void do_fullscreen(commands_t *, client_info_t *);
+static void do_commands(const commands_t *, client_info_t *);
+static void do_help(const commands_t *, client_info_t *);
+static void do_syntax(const commands_t *, client_info_t *);
+static void do_auth(const commands_t *, client_info_t *);
+static void do_mrl(const commands_t *, client_info_t *);
+static void do_playlist(const commands_t *, client_info_t *);
+static void do_play(const commands_t *, client_info_t *);
+static void do_stop(const commands_t *, client_info_t *);
+static void do_pause(const commands_t *, client_info_t *);
+static void do_exit(const commands_t *, client_info_t *);
+static void do_fullscreen(const commands_t *, client_info_t *);
 #ifdef HAVE_XINERAMA
-static void do_xinerama_fullscreen(commands_t *, client_info_t *);
+static void do_xinerama_fullscreen(const commands_t *, client_info_t *);
 #endif
-static void do_get(commands_t *, client_info_t *);
-static void do_set(commands_t *, client_info_t *);
-static void do_gui(commands_t *, client_info_t *);
-static void do_event(commands_t *, client_info_t *);
-static void do_seek(commands_t *, client_info_t *);
-static void do_halt(commands_t *, client_info_t *);
-static void do_snap(commands_t *, client_info_t *);
+static void do_get(const commands_t *, client_info_t *);
+static void do_set(const commands_t *, client_info_t *);
+static void do_gui(const commands_t *, client_info_t *);
+static void do_event(const commands_t *, client_info_t *);
+static void do_seek(const commands_t *, client_info_t *);
+static void do_halt(const commands_t *, client_info_t *);
+static void do_snap(const commands_t *, client_info_t *);
 
 static void handle_client_command(client_info_t *);
 
@@ -209,13 +216,13 @@ static void handle_client_command(client_info_t *);
 #define PASSWD_USER_DENIED  4
 
 struct commands_s {
-  char         *command;
+  const char   *command;
   int           argtype;
   int           public;
   int           need_auth;
   cmd_func_t    function;
-  char         *help;
-  char         *syntax;
+  const char   *help;
+  const char   *syntax;
 };
 
 struct client_info_s {
@@ -254,7 +261,7 @@ typedef struct {
   char              buf[256];
 } fileobj_t;
 
-static commands_t commands[] = {
+static const commands_t commands[] = {
   { "commands",    NO_ARGS,         NOT_PUBLIC,      AUTH_UNNEEDED, do_commands,
     "Display all available commands, tab separated, dot terminated.", 
     "commands"
@@ -408,8 +415,8 @@ static commands_t commands[] = {
   } 
 };
 
-static struct {
-  char        *name;
+static const struct {
+  const char  *name;
   int          status;
 } status_struct[] = {
   { "XINE_STATUS_IDLE"   , XINE_STATUS_IDLE },
@@ -419,8 +426,8 @@ static struct {
   { NULL                 , -1               }
 };
 
-static struct {
-  char        *name;
+static const struct {
+  const char  *name;
   int          speed;
 } speeds_struct[] = {
   { "XINE_SPEED_PAUSE"   , XINE_SPEED_PAUSE  },
@@ -448,7 +455,7 @@ static int sock_create(const char *service, const char *transport, struct sockad
   struct protoent *itransport;
   int                sock;
   int                type;
-  int                proto;
+  int                proto = 0;
 
   memset(sin, 0, sizeof(*sin));
 
@@ -460,16 +467,16 @@ static int sock_create(const char *service, const char *transport, struct sockad
 
     if(!iservice)
       sock_err("Service not registered: %s\n", service);
-    
-    sin->sin_port = iservice->s_port;
+    else
+      sin->sin_port = iservice->s_port;
   }
 
   itransport = getprotobyname(transport);
 
-  if(!transport)
+  if(!itransport)
     sock_err("Protocol not registered: %s\n", transport);
-
-  proto = itransport->p_proto;
+  else
+    proto = itransport->p_proto;
 
   if(!strcmp(transport, "udp"))
     type = SOCK_DGRAM;
@@ -522,7 +529,7 @@ static int sock_check_opened(int socket) {
 /*
  * Write to socket.
  */
-static int _sock_write(int socket, char *buf, int len) {
+static int _sock_write(int socket, const char *buf, int len) {
   ssize_t  size;
   int      wlen = 0;
   
@@ -546,7 +553,7 @@ static int _sock_write(int socket, char *buf, int len) {
   return wlen;
 }
 
-static int __attribute__ ((format (printf, 3, 4))) __sock_write(int socket, int cr, char *msg, ...) {
+static int __attribute__ ((format (printf, 3, 4))) __sock_write(int socket, int cr, const char *msg, ...) {
   char     buf[_BUFSIZ];
   va_list  args;
   
@@ -607,6 +614,9 @@ static int sock_client(const char *host, const char *service, const char *transp
   int                  sock;
   
   sock = sock_create(service, transport, &fsin.in);
+  if (sock < 0) {
+    return -1;
+  }
 
   if ((fsin.in.sin_addr.s_addr = inet_addr(host)) == INADDR_NONE) {
     ihost = gethostbyname(host);
@@ -1338,7 +1348,10 @@ static int sock_serv(const char *service, const char *transport, int queue_lengt
   int                 on = 1;
 
   sock = sock_create(service, transport, &fsin.in);
-  
+  if (sock < 0) {
+    return -1;
+  }
+
   setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, &on, sizeof(int));
   
   if(bind(sock, &fsin.sa, sizeof(fsin.in)) < 0)
@@ -1353,12 +1366,12 @@ static int sock_serv(const char *service, const char *transport, int queue_lengt
 /*
  * Read from socket.
  */
-static int sock_read(int socket, char *buf, int len) {
+static ssize_t sock_read(int socket, char *buf, size_t len) {
   char    *pbuf;
-  int      r, rr;
+  ssize_t  r, rr;
   void    *nl;
   
-  if((socket < 0) || (buf == NULL))
+  if((socket < 0) || (buf == NULL) || (len < 1))
     return -1;
 
   if(!sock_check_opened(socket))
@@ -1502,7 +1515,7 @@ static int server_load_passwd(const char *passwdfilename) {
 static int is_user_in_passwds(client_info_t *client_info) {
   int i;
   
-  if((client_info == NULL) || (client_info->name == NULL))
+  if(client_info == NULL)
     return 0;
   
   for(i = 0; passwds[i]->ident != NULL; i++) {
@@ -1514,7 +1527,7 @@ static int is_user_in_passwds(client_info_t *client_info) {
 static int is_user_allowed(client_info_t *client_info) {
   int i;
   
-  if((client_info == NULL) || (client_info->name == NULL) || (client_info->passwd == NULL))
+  if((client_info == NULL) || (client_info->passwd == NULL))
     return PASSWD_USER_DENIED;
   
   for(i = 0; passwds[i]->ident != NULL; i++) {
@@ -1592,9 +1605,10 @@ static void check_client_auth(client_info_t *client_info) {
 }
 
 static void handle_xine_error(client_info_t *client_info) {
+  gGui_t *gui = gGui;
   int err;
   
-  err = xine_get_error(gGui->stream);
+  err = xine_get_error(gui->stream);
   
   switch(err) {
     
@@ -1606,14 +1620,14 @@ static void handle_xine_error(client_info_t *client_info) {
     sock_write(client_info->socket,
 	       "xine engine error:\n"
 	       "There is no available input plugin available to handle '%s'.\n",
-	       gGui->mmk.mrl);
+	       gui->mmk.mrl);
     break;
     
   case XINE_ERROR_NO_DEMUX_PLUGIN:
     sock_write(client_info->socket, 
 	       "xine engine error:\n"
 	       "There is no available demuxer plugin to handle '%s'.\n", 
-	       gGui->mmk.mrl);
+	       gui->mmk.mrl);
     break;
     
   default:
@@ -1663,7 +1677,7 @@ static int is_arg_contain(client_info_t *client_info, int pos, const char *arg)
 /*
  * Set current command line from line.
  */
-static void set_command_line(client_info_t *client_info, char *line) {
+static void set_command_line(client_info_t *client_info, const char *line) {
 
   if(client_info && line && strlen(line)) {
 
@@ -1677,7 +1691,7 @@ static void set_command_line(client_info_t *client_info, char *line) {
 /*
  * Display help of given command.
  */
-static void command_help(commands_t *command, client_info_t *client_info) {
+static void command_help(const commands_t *command, client_info_t *client_info) {
 
   if(command) {
     if(command->help) {
@@ -1693,7 +1707,7 @@ static void command_help(commands_t *command, client_info_t *client_info) {
 /*
  * Display syntax of given command.
  */
-static void command_syntax(commands_t *command, client_info_t *client_info) {
+static void command_syntax(const commands_t *command, client_info_t *client_info) {
   
   if(command) {
     if(command->syntax) {
@@ -1706,7 +1720,7 @@ static void command_syntax(commands_t *command, client_info_t *client_info) {
   }
 }
 
-static void do_commands(commands_t *cmd, client_info_t *client_info) {
+static void do_commands(const commands_t *cmd, client_info_t *client_info) {
   int i = 0;
   char buf[_BUFSIZ];
 
@@ -1722,7 +1736,7 @@ static void do_commands(commands_t *cmd, client_info_t *client_info) {
   sock_write(client_info->socket, "%s", buf);
 }
 
-static void do_help(commands_t *cmd, client_info_t *client_info) {
+static void do_help(const commands_t *cmd, client_info_t *client_info) {
   char buf[_BUFSIZ] = "Available commands are:\n       ";
 
   if(!client_info->command.num_args) {
@@ -1780,7 +1794,7 @@ static void do_help(commands_t *cmd, client_info_t *client_info) {
   }
 }
 
-static void do_syntax(commands_t *command, client_info_t *client_info) {
+static void do_syntax(const commands_t *command, client_info_t *client_info) {
   int i;
   
   for(i = 0; commands[i].command != NULL; i++) {
@@ -1793,7 +1807,7 @@ static void do_syntax(commands_t *command, client_info_t *client_info) {
   sock_write(client_info->socket, "Unknown command '%s'.\n", (get_arg(client_info, 1)));
 }
 
-static void do_auth(commands_t *cmd, client_info_t *client_info) {
+static void do_auth(const commands_t *cmd, client_info_t *client_info) {
   int nargs;
   
   nargs = is_args(client_info);
@@ -1830,33 +1844,34 @@ static void do_auth(commands_t *cmd, client_info_t *client_info) {
   }
 }
 
-static void do_mrl(commands_t *cmd, client_info_t *client_info) {
+static void do_mrl(const commands_t *cmd, client_info_t *client_info) {
+  gGui_t *gui = gGui;
   int nargs;
 
   nargs = is_args(client_info);
   if(nargs) {
     if(nargs == 1) {
       if(is_arg_contain(client_info, 1, "next")) {
-	gGui->ignore_next = 1;
-	xine_stop (gGui->stream);
-	gGui->ignore_next = 0;
+	gui->ignore_next = 1;
+	xine_stop (gui->stream);
+	gui->ignore_next = 0;
 	gui_playlist_start_next();
       }
       else if(is_arg_contain(client_info, 1, "prev")) {
-	gGui->ignore_next = 1;
-	xine_stop (gGui->stream);
-	gGui->playlist.cur--;
-	if ((gGui->playlist.cur >= 0) && (gGui->playlist.cur < gGui->playlist.num)) {
+	gui->ignore_next = 1;
+	xine_stop (gui->stream);
+	gui->playlist.cur--;
+	if ((gui->playlist.cur >= 0) && (gui->playlist.cur < gui->playlist.num)) {
 	  gui_set_current_mmk(mediamark_get_current_mmk());
-	  (void) gui_xine_open_and_play(gGui->mmk.mrl, gGui->mmk.sub, 0, 
-					gGui->mmk.start, gGui->mmk.av_offset, gGui->mmk.spu_offset, 1);
+	  (void) gui_xine_open_and_play(gui->mmk.mrl, gui->mmk.sub, 0, 
+					gui->mmk.start, gui->mmk.av_offset, gui->mmk.spu_offset, 1);
   
 	} 
 	else {
-	  gGui->playlist.cur = 0;
+	  gui->playlist.cur = 0;
 	  gui_display_logo();
 	}
-	gGui->ignore_next = 0;
+	gui->ignore_next = 0;
       }
     }
     else if(nargs >= 2) {
@@ -1872,25 +1887,26 @@ static void do_mrl(commands_t *cmd, client_info_t *client_info) {
       else if (is_arg_contain(client_info, 1, "play")) {
 	gui_dndcallback((char *)(get_arg(client_info, 2)));
 	
-	if((xine_get_status(gGui->stream) != XINE_STATUS_STOP)) {
-	  gGui->ignore_next = 1;
-	  xine_stop(gGui->stream);
-	  gGui->ignore_next = 0;
+	if((xine_get_status(gui->stream) != XINE_STATUS_STOP)) {
+	  gui->ignore_next = 1;
+	  xine_stop(gui->stream);
+	  gui->ignore_next = 0;
 	}
-	gui_set_current_mmk(gGui->playlist.mmk[gGui->playlist.num - 1]);
-	if(!(xine_open(gGui->stream, gGui->mmk.mrl) 
-	     && xine_play (gGui->stream, 0, gGui->mmk.start))) {
+	gui_set_current_mmk(gui->playlist.mmk[gui->playlist.num - 1]);
+	if(!(xine_open(gui->stream, gui->mmk.mrl) 
+	     && xine_play (gui->stream, 0, gui->mmk.start))) {
 	  handle_xine_error(client_info);
 	  gui_display_logo();
 	}
 	else
-	  gGui->logo_mode = 0;
+	  gui->logo_mode = 0;
       }
     }
   }
 }
 
-static void do_playlist(commands_t *cmd, client_info_t *client_info) {
+static void do_playlist(const commands_t *cmd, client_info_t *client_info) {
+  gGui_t *gui = gGui;
   int nargs;
   
   nargs = is_args(client_info);
@@ -1901,10 +1917,10 @@ static void do_playlist(commands_t *cmd, client_info_t *client_info) {
       if(is_arg_contain(client_info, 1, "show")) {
 	int i;
 
-	if(gGui->playlist.num) {
-	  for(i = 0; i < gGui->playlist.num; i++) {
+	if(gui->playlist.num) {
+	  for(i = 0; i < gui->playlist.num; i++) {
 	    sock_write(client_info->socket, "%2s %5d %s\n", 
-		       (i == gGui->playlist.cur) ? "*>" : "", i, gGui->playlist.mmk[i]->mrl);
+		       (i == gui->playlist.cur) ? "*>" : "", i, gui->playlist.mmk[i]->mrl);
 	  }
 	}
 	else
@@ -1922,30 +1938,30 @@ static void do_playlist(commands_t *cmd, client_info_t *client_info) {
       }
       else if((first = is_arg_contain(client_info, 1, "first")) || is_arg_contain(client_info, 1, "last")) {
 
-	if(gGui->playlist.num) {
-	  int entry = (first) ? 0 : gGui->playlist.num - 1;
+	if(gui->playlist.num) {
+	  int entry = (first) ? 0 : gui->playlist.num - 1;
 	  
-	  if(entry != gGui->playlist.cur) {
+	  if(entry != gui->playlist.cur) {
 	    
-	    if(xine_get_status(gGui->stream) != XINE_STATUS_STOP) {
-	      gGui->ignore_next = 1;
-	      xine_stop (gGui->stream);
-	      gGui->ignore_next = 0;
+	    if(xine_get_status(gui->stream) != XINE_STATUS_STOP) {
+	      gui->ignore_next = 1;
+	      xine_stop (gui->stream);
+	      gui->ignore_next = 0;
 	    }
 
-	    gGui->playlist.cur = entry;
+	    gui->playlist.cur = entry;
 	    gui_set_current_mmk(mediamark_get_current_mmk());
 	    gui_play(NULL, NULL);
 	  }
 	}
       }
       else if(is_arg_contain(client_info, 1, "stop")) {
-	if(xine_get_status(gGui->stream) != XINE_STATUS_STOP)
-	  gGui->playlist.control |= PLAYLIST_CONTROL_STOP;
+	if(xine_get_status(gui->stream) != XINE_STATUS_STOP)
+	  gui->playlist.control |= PLAYLIST_CONTROL_STOP;
       }
       else if(is_arg_contain(client_info, 1, "continue")) {
-	if(xine_get_status(gGui->stream) != XINE_STATUS_STOP)
-	  gGui->playlist.control &= ~PLAYLIST_CONTROL_STOP;
+	if(xine_get_status(gui->stream) != XINE_STATUS_STOP)
+	  gui->playlist.control &= ~PLAYLIST_CONTROL_STOP;
       }
 
     }
@@ -1956,14 +1972,14 @@ static void do_playlist(commands_t *cmd, client_info_t *client_info) {
 	
 	j = atoi(get_arg(client_info, 2));
 	
-	if((j >= 0) && (j <= gGui->playlist.num)) {
-	  gGui->playlist.cur = j;
+	if((j >= 0) && (j <= gui->playlist.num)) {
+	  gui->playlist.cur = j;
 	  gui_set_current_mmk(mediamark_get_current_mmk());
 
-	  if(xine_get_status(gGui->stream) != XINE_STATUS_STOP) {
-	    gGui->ignore_next = 1;
-	    xine_stop(gGui->stream);
-	    gGui->ignore_next = 0;
+	  if(xine_get_status(gui->stream) != XINE_STATUS_STOP) {
+	    gui->ignore_next = 1;
+	    xine_stop(gui->stream);
+	    gui->ignore_next = 0;
 
 	    do_play(cmd, client_info);
 	  }
@@ -1977,7 +1993,7 @@ static void do_playlist(commands_t *cmd, client_info_t *client_info) {
 	  
 	  mediamark_free_mediamarks();
 	  
-	  if(xine_get_status(gGui->stream) != XINE_STATUS_STOP)
+	  if(xine_get_status(gui->stream) != XINE_STATUS_STOP)
 	    gui_stop(NULL, NULL);
 	  
 	  enable_playback_controls(0);
@@ -1989,33 +2005,33 @@ static void do_playlist(commands_t *cmd, client_info_t *client_info) {
 	  
 	  if(j >= 0) {
 
-	    if((gGui->playlist.cur == j) && ((xine_get_status(gGui->stream) != XINE_STATUS_STOP)))
+	    if((gui->playlist.cur == j) && ((xine_get_status(gui->stream) != XINE_STATUS_STOP)))
 	      gui_stop(NULL, NULL);
 	    
 	    mediamark_free_entry(j);
 	    
-	    for(i = j; i < gGui->playlist.num; i++)
-	      gGui->playlist.mmk[i] = gGui->playlist.mmk[i + 1];
+	    for(i = j; i < gui->playlist.num; i++)
+	      gui->playlist.mmk[i] = gui->playlist.mmk[i + 1];
 	    
-	    gGui->playlist.mmk = (mediamark_t **) realloc(gGui->playlist.mmk, sizeof(mediamark_t *) * (gGui->playlist.num + 2));
+	    gui->playlist.mmk = (mediamark_t **) realloc(gui->playlist.mmk, sizeof(mediamark_t *) * (gui->playlist.num + 2));
 	    
-	    gGui->playlist.mmk[gGui->playlist.num + 1] = NULL;
+	    gui->playlist.mmk[gui->playlist.num + 1] = NULL;
 	    
-	    gGui->playlist.cur = 0;
+	    gui->playlist.cur = 0;
 	  }
 	}
 	
 	if(playlist_is_running())
 	  playlist_update_playlist();
 
-	if(gGui->playlist.num)
+	if(gui->playlist.num)
 	  gui_set_current_mmk(mediamark_get_current_mmk());
 	else {
 	  
 	  if(is_playback_widgets_enabled())
 	    enable_playback_controls(0);
 	  
-	  if(xine_get_status(gGui->stream) != XINE_STATUS_STOP)
+	  if(xine_get_status(gui->stream) != XINE_STATUS_STOP)
 	    gui_stop(NULL, NULL);
 	  
 	  gui_set_current_mmk(NULL);
@@ -2025,58 +2041,62 @@ static void do_playlist(commands_t *cmd, client_info_t *client_info) {
   }
 }
 
-static void do_play(commands_t *cmd, client_info_t *client_info) {
+static void do_play(const commands_t *cmd, client_info_t *client_info) {
+  gGui_t *gui = gGui;
 
-  if (xine_get_status (gGui->stream) != XINE_STATUS_PLAY) {
-    if(!(xine_open(gGui->stream, gGui->mmk.mrl) && xine_play (gGui->stream, 0, gGui->mmk.start))) {
+  if (xine_get_status (gui->stream) != XINE_STATUS_PLAY) {
+    if(!(xine_open(gui->stream, gui->mmk.mrl) && xine_play (gui->stream, 0, gui->mmk.start))) {
       handle_xine_error(client_info);
       gui_display_logo();
     }
     else
-      gGui->logo_mode = 0;
+      gui->logo_mode = 0;
   } 
   else {
-    xine_set_param(gGui->stream, XINE_PARAM_SPEED, XINE_SPEED_NORMAL);
+    xine_set_param(gui->stream, XINE_PARAM_SPEED, XINE_SPEED_NORMAL);
   }
 
 }
 
-static void do_stop(commands_t *cmd, client_info_t *client_info) {
-  gGui->ignore_next = 1;
-  xine_stop(gGui->stream);
-  gGui->ignore_next = 0; 
+static void do_stop(const commands_t *cmd, client_info_t *client_info) {
+  gGui_t *gui = gGui;
+  gui->ignore_next = 1;
+  xine_stop(gui->stream);
+  gui->ignore_next = 0; 
   gui_display_logo();
 }
 
-static void do_pause(commands_t *cmd, client_info_t *client_info) {
+static void do_pause(const commands_t *cmd, client_info_t *client_info) {
+  gGui_t *gui = gGui;
 
-  if (xine_get_param (gGui->stream, XINE_PARAM_SPEED) != XINE_SPEED_PAUSE)
-    xine_set_param(gGui->stream, XINE_PARAM_SPEED, XINE_SPEED_PAUSE);
+  if (xine_get_param (gui->stream, XINE_PARAM_SPEED) != XINE_SPEED_PAUSE)
+    xine_set_param(gui->stream, XINE_PARAM_SPEED, XINE_SPEED_PAUSE);
   else
-    xine_set_param(gGui->stream, XINE_PARAM_SPEED, XINE_SPEED_NORMAL);
+    xine_set_param(gui->stream, XINE_PARAM_SPEED, XINE_SPEED_NORMAL);
 }
 
-static void do_exit(commands_t *cmd, client_info_t *client_info) {
+static void do_exit(const commands_t *cmd, client_info_t *client_info) {
   if(client_info) {
     client_info->finished = 1;
   }
 }
 
-static void do_fullscreen(commands_t *cmd, client_info_t *client_info) {
+static void do_fullscreen(const commands_t *cmd, client_info_t *client_info) {
   action_id_t action = ACTID_TOGGLE_FULLSCREEN;
 
   gui_execute_action_id(action);
 }
 
 #ifdef HAVE_XINERAMA
-static void do_xinerama_fullscreen(commands_t *cmd, client_info_t *client_info) {
+static void do_xinerama_fullscreen(const commands_t *cmd, client_info_t *client_info) {
   action_id_t action = ACTID_TOGGLE_XINERAMA_FULLSCREEN;
 
   gui_execute_action_id(action);
 }
 #endif
 
-static void do_get(commands_t *cmd, client_info_t *client_info) {
+static void do_get(const commands_t *cmd, client_info_t *client_info) {
+  gGui_t *gui = gGui;
   int nargs;
   
   nargs = is_args(client_info);
@@ -2087,7 +2107,7 @@ static void do_get(commands_t *cmd, client_info_t *client_info) {
 	int  status;
 
 	strcpy(buf, "Current status: ");
-	status = xine_get_status(gGui->stream);
+	status = xine_get_status(gui->stream);
 	
 	if(status <= XINE_STATUS_QUIT)
 	  strlcat(buf, status_struct[status].name, sizeof(buf));
@@ -2102,7 +2122,7 @@ static void do_get(commands_t *cmd, client_info_t *client_info) {
 	size_t i;
 	
 	strcpy(buf, "Current speed: ");
-	speed = xine_get_param(gGui->stream, XINE_PARAM_SPEED);
+	speed = xine_get_param(gui->stream, XINE_PARAM_SPEED);
 
 	for(i = 0; speeds_struct[i].name != NULL; i++) {
 	  if(speed == speeds_struct[i].speed)
@@ -2121,7 +2141,7 @@ static void do_get(commands_t *cmd, client_info_t *client_info) {
 	int pos_stream;
 	int pos_time;
 	int length_time;
-	xine_get_pos_length(gGui->stream,
+	xine_get_pos_length(gui->stream,
 			    &pos_stream,
 			    &pos_time,
 			    &length_time);
@@ -2133,7 +2153,7 @@ static void do_get(commands_t *cmd, client_info_t *client_info) {
 	int pos_stream;
 	int pos_time;
 	int length_time;
-	xine_get_pos_length(gGui->stream,
+	xine_get_pos_length(gui->stream,
 			    &pos_stream,
 			    &pos_time,
 			    &length_time);
@@ -2143,7 +2163,7 @@ static void do_get(commands_t *cmd, client_info_t *client_info) {
       else if(is_arg_contain(client_info, 1, "loop")) {
 	char buf[64] = "Current loop mode is: ";
 
-	switch(gGui->playlist.loop) {
+	switch(gui->playlist.loop) {
 	case PLAYLIST_LOOP_NO_LOOP:
 	  strlcat(buf, "'No Loop'", sizeof(buf));
 	  break;
@@ -2171,26 +2191,26 @@ static void do_get(commands_t *cmd, client_info_t *client_info) {
       if(is_arg_contain(client_info, 1, "audio")) {
 	if(is_arg_contain(client_info, 2, "channel")) {
 	  sock_write(client_info->socket, "Current audio channel: %d\n", 
-		     (xine_get_param(gGui->stream, XINE_PARAM_AUDIO_CHANNEL_LOGICAL)));
+		     (xine_get_param(gui->stream, XINE_PARAM_AUDIO_CHANNEL_LOGICAL)));
 	}
 	else if(is_arg_contain(client_info, 2, "lang")) {
 	  char buf[XINE_LANG_MAX];
-
-	  xine_get_audio_lang(gGui->stream,
-	                      xine_get_param(gGui->stream, XINE_PARAM_AUDIO_CHANNEL_LOGICAL),
-			      &buf[0]);
+          int channel = xine_get_param(gui->stream, XINE_PARAM_AUDIO_CHANNEL_LOGICAL);
+          if (!xine_get_audio_lang(gui->stream, channel, &buf[0])) {
+            snprintf(buf, sizeof(buf), "%3d", channel);
+          }
 	  sock_write(client_info->socket, "Current audio language: %s\n", buf);
 	}
 	else if(is_arg_contain(client_info, 2, "volume")) {
-	  if(gGui->mixer.caps & MIXER_CAP_VOL) { 
-	    sock_write(client_info->socket, "Current audio volume: %d\n", gGui->mixer.volume_level);
+	  if(gui->mixer.caps & MIXER_CAP_VOL) { 
+	    sock_write(client_info->socket, "Current audio volume: %d\n", gui->mixer.volume_level);
 	  }
 	  else
 	    sock_write(client_info->socket, "Audio is disabled.\n");
 	}
 	else if(is_arg_contain(client_info, 2, "mute")) {
-	  if(gGui->mixer.caps & MIXER_CAP_MUTE) {
-	    sock_write(client_info->socket, "Current audio mute: %d\n", gGui->mixer.mute);
+	  if(gui->mixer.caps & MIXER_CAP_MUTE) {
+	    sock_write(client_info->socket, "Current audio mute: %d\n", gui->mixer.mute);
 	  }
 	  else
 	    sock_write(client_info->socket, "Audio is disabled.\n");
@@ -2199,20 +2219,20 @@ static void do_get(commands_t *cmd, client_info_t *client_info) {
       else if(is_arg_contain(client_info, 1, "spu")) {
 	if(is_arg_contain(client_info, 2, "channel")) {
 	  sock_write(client_info->socket, "Current spu channel: %d\n", 
-		     (xine_get_param(gGui->stream, XINE_PARAM_SPU_CHANNEL)));
+		     (xine_get_param(gui->stream, XINE_PARAM_SPU_CHANNEL)));
 	}
 	else if(is_arg_contain(client_info, 2, "lang")) {
-	  char buf[XINE_LANG_MAX];
-
-	  xine_get_spu_lang (gGui->stream,
-	                     xine_get_param(gGui->stream, XINE_PARAM_SPU_CHANNEL),
-			     &buf[0]);
+          char buf[XINE_LANG_MAX];
+          int channel = xine_get_param(gui->stream, XINE_PARAM_SPU_CHANNEL);
+          if (!xine_get_spu_lang (gui->stream, channel, &buf[0])) {
+            snprintf(buf, sizeof(buf), "%3d", channel);
+          }
 	  sock_write(client_info->socket, "Current spu language: %s\n", buf);
 	}
 	else if(is_arg_contain(client_info, 2, "offset")) {
 	  int offset;
 
-	  offset = xine_get_param(gGui->stream, XINE_PARAM_SPU_OFFSET);
+	  offset = xine_get_param(gui->stream, XINE_PARAM_SPU_OFFSET);
 	  sock_write(client_info->socket, "Current spu offset: %d\n", offset);
 	}
       }
@@ -2220,7 +2240,7 @@ static void do_get(commands_t *cmd, client_info_t *client_info) {
 	if(is_arg_contain(client_info, 2, "offset")) {
 	  int offset;
 	  
-	  offset = xine_get_param(gGui->stream, XINE_PARAM_AV_OFFSET);
+	  offset = xine_get_param(gui->stream, XINE_PARAM_AV_OFFSET);
 	  sock_write(client_info->socket, "Current A/V offset: %d\n", offset);
 	}
       }
@@ -2228,7 +2248,8 @@ static void do_get(commands_t *cmd, client_info_t *client_info) {
   }
 }
 
-static void do_set(commands_t *cmd, client_info_t *client_info) {
+static void do_set(const commands_t *cmd, client_info_t *client_info) {
+  gGui_t *gui = gGui;
   int nargs;
 
   nargs = is_args(client_info);
@@ -2258,13 +2279,13 @@ static void do_set(commands_t *cmd, client_info_t *client_info) {
 	else
 	  speed = atoi((get_arg(client_info, 2)));
 	
-	xine_set_param(gGui->stream, XINE_PARAM_SPEED, speed);
+	xine_set_param(gui->stream, XINE_PARAM_SPEED, speed);
       }
       else if(is_arg_contain(client_info, 1, "loop")) {
 	int i;
-	struct {
-	  char *mode;
-	  int   loop_mode;
+	static const struct {
+	  const char *mode;
+	  int         loop_mode;
 	} loop_modes[] = {
 	  { "no",       PLAYLIST_LOOP_NO_LOOP   },
 	  { "loop",     PLAYLIST_LOOP_LOOP      },
@@ -2277,7 +2298,7 @@ static void do_set(commands_t *cmd, client_info_t *client_info) {
 
 	for(i = 0; loop_modes[i].mode; i++) {
 	  if(!strncmp(arg, loop_modes[i].mode, strlen(arg))) {
-	    gGui->playlist.loop = loop_modes[i].loop_mode;
+	    gui->playlist.loop = loop_modes[i].loop_mode;
 	    return;
 	  }
 	}
@@ -2286,25 +2307,25 @@ static void do_set(commands_t *cmd, client_info_t *client_info) {
     else if(nargs >= 3) {
       if(is_arg_contain(client_info, 1, "audio")) {
 	if(is_arg_contain(client_info, 2, "channel")) {
-	  xine_set_param(gGui->stream, XINE_PARAM_AUDIO_CHANNEL_LOGICAL, (atoi(get_arg(client_info, 3))));
+	  xine_set_param(gui->stream, XINE_PARAM_AUDIO_CHANNEL_LOGICAL, (atoi(get_arg(client_info, 3))));
 	}
 	else if(is_arg_contain(client_info, 2, "volume")) {
-	  if(gGui->mixer.caps & MIXER_CAP_VOL) { 
+	  if(gui->mixer.caps & MIXER_CAP_VOL) { 
 	    int vol = atoi(get_arg(client_info, 3));
 	    
 	    if(vol < 0) vol = 0;
 	    if(vol > 100) vol = 100;
 	    
-	    gGui->mixer.volume_level = vol;
-	    xine_set_param(gGui->stream, XINE_PARAM_AUDIO_VOLUME, gGui->mixer.volume_level);
+	    gui->mixer.volume_level = vol;
+	    xine_set_param(gui->stream, XINE_PARAM_AUDIO_VOLUME, gui->mixer.volume_level);
 	  }
 	  else
 	    sock_write(client_info->socket, "Audio is disabled.\n");
 	}
 	else if(is_arg_contain(client_info, 2, "mute")) {
-	  if(gGui->mixer.caps & MIXER_CAP_MUTE) {
-	    gGui->mixer.mute = get_bool_value((get_arg(client_info, 3)));
-	    xine_set_param(gGui->stream, XINE_PARAM_AUDIO_MUTE, gGui->mixer.mute);
+	  if(gui->mixer.caps & MIXER_CAP_MUTE) {
+	    gui->mixer.mute = get_bool_value((get_arg(client_info, 3)));
+	    xine_set_param(gui->stream, XINE_PARAM_AUDIO_MUTE, gui->mixer.mute);
 	  }
 	  else
 	    sock_write(client_info->socket, "Audio is disabled.\n");
@@ -2312,22 +2333,23 @@ static void do_set(commands_t *cmd, client_info_t *client_info) {
       }
       else if(is_arg_contain(client_info, 1, "spu")) {
 	if(is_arg_contain(client_info, 2, "channel")) {
-	  xine_set_param(gGui->stream, XINE_PARAM_SPU_CHANNEL, (atoi(get_arg(client_info, 3))));
+	  xine_set_param(gui->stream, XINE_PARAM_SPU_CHANNEL, (atoi(get_arg(client_info, 3))));
 	}
 	else if(is_arg_contain(client_info, 2, "offset")) {
-	  xine_set_param(gGui->stream, XINE_PARAM_SPU_OFFSET, (atoi(get_arg(client_info, 3))));
+	  xine_set_param(gui->stream, XINE_PARAM_SPU_OFFSET, (atoi(get_arg(client_info, 3))));
 	}
       }
       else if(is_arg_contain(client_info, 1, "av")) {
 	if(is_arg_contain(client_info, 2, "offset")) {
-	  xine_set_param(gGui->stream, XINE_PARAM_AV_OFFSET, (atoi(get_arg(client_info, 3))));
+	  xine_set_param(gui->stream, XINE_PARAM_AV_OFFSET, (atoi(get_arg(client_info, 3))));
 	}
       }
     }
   }
 }
 
-static void do_gui(commands_t *cmd, client_info_t *client_info) {
+static void do_gui(const commands_t *cmd, client_info_t *client_info) {
+  gGui_t *gui = gGui;
   int nargs;
   
   nargs = is_args(client_info);
@@ -2383,16 +2405,17 @@ static void do_gui(commands_t *cmd, client_info_t *client_info) {
       }
 
       /* Flush event when xine !play */
-      if(flushing && ((xine_get_status(gGui->stream) != XINE_STATUS_PLAY))) {
-	XLockDisplay(gGui->display);
-	XSync(gGui->display, False);
-	XUnlockDisplay(gGui->display);
+      if(flushing && ((xine_get_status(gui->stream) != XINE_STATUS_PLAY))) {
+	XLockDisplay(gui->display);
+	XSync(gui->display, False);
+	XUnlockDisplay(gui->display);
       }
     }
   }
 }
 
-static void do_event(commands_t *cmd, client_info_t *client_info) {
+static void do_event(const commands_t *cmd, client_info_t *client_info) {
+  gGui_t *gui = gGui;
   xine_event_t   xine_event;
   int            nargs;
   
@@ -2403,9 +2426,9 @@ static void do_event(commands_t *cmd, client_info_t *client_info) {
 
     if(nargs == 1) {
       const char *arg = get_arg(client_info, 1);
-      struct {
-	char     *name;
-	int       type;
+      static const struct {
+	const char *name;
+	int         type;
       } events_struct[] = {
 	{ "menu1"   , XINE_EVENT_INPUT_MENU1    },
 	{ "menu2"   , XINE_EVENT_INPUT_MENU2    },
@@ -2465,19 +2488,20 @@ static void do_event(commands_t *cmd, client_info_t *client_info) {
     if(xine_event.type != 0) {
       xine_event.data_length = 0;
       xine_event.data        = NULL;
-      xine_event.stream      = gGui->stream;
+      xine_event.stream      = gui->stream;
       gettimeofday(&xine_event.tv, NULL);
       
-      xine_event_send(gGui->stream, &xine_event);
+      xine_event_send(gui->stream, &xine_event);
     }
 
   }
 }
 
-static void do_seek(commands_t *cmd, client_info_t *client_info) {
+static void do_seek(const commands_t *cmd, client_info_t *client_info) {
+  gGui_t *gui = gGui;
   int            nargs;
   
-  if((xine_get_stream_info(gGui->stream, XINE_STREAM_INFO_SEEKABLE)) == 0)
+  if((xine_get_stream_info(gui->stream, XINE_STREAM_INFO_SEEKABLE)) == 0)
     return;
   
   nargs = is_args(client_info);
@@ -2492,15 +2516,15 @@ static void do_seek(commands_t *cmd, client_info_t *client_info) {
 	if(pos > 100) pos = 100;
 	if(pos < 0) pos = 0;
 	
-	gGui->ignore_next = 1;
-	if(!xine_play(gGui->stream, ((int) (655.35 * pos)), 0)) {
-	  gui_handle_xine_error(gGui->stream, NULL);
+	gui->ignore_next = 1;
+	if(!xine_play(gui->stream, ((int) (655.35 * pos)), 0)) {
+	  gui_handle_xine_error(gui->stream, NULL);
 	  gui_display_logo();
 	}
 	else
-	  gGui->logo_mode = 0;
+	  gui->logo_mode = 0;
 
-	gGui->ignore_next = 0;
+	gui->ignore_next = 0;
 	
       }
 
@@ -2512,7 +2536,7 @@ static void do_seek(commands_t *cmd, client_info_t *client_info) {
 	
 	if(((arg[0] == '+') || (arg[0] == '-')) && (isdigit(arg[1]))) {
 
-	  if(gui_xine_get_pos_length(gGui->stream, NULL, &msec, NULL)) {
+	  if(gui_xine_get_pos_length(gui->stream, NULL, &msec, NULL)) {
 	    msec /= 1000;
 	    
 	    if((msec + pos) < 0) 
@@ -2525,22 +2549,22 @@ static void do_seek(commands_t *cmd, client_info_t *client_info) {
 	  
 	  msec *= 1000;
 	  
-	  gGui->ignore_next = 1;
-	  if(!xine_play(gGui->stream, 0, msec)) {
-	    gui_handle_xine_error(gGui->stream, NULL);
+	  gui->ignore_next = 1;
+	  if(!xine_play(gui->stream, 0, msec)) {
+	    gui_handle_xine_error(gui->stream, NULL);
 	    gui_display_logo();
 	  }
 	  else
-	    gGui->logo_mode = 0;
+	    gui->logo_mode = 0;
 	
-	  gGui->ignore_next = 0;
+	  gui->ignore_next = 0;
 	}
       }
     }
   }
 }
 
-static void do_halt(commands_t *cmd, client_info_t *client_info) {
+static void do_halt(const commands_t *cmd, client_info_t *client_info) {
   gui_exit(NULL, NULL);
 }
 
@@ -2550,8 +2574,9 @@ static void network_messenger(void *data, char *message) {
   sock_write(socket, "%s", message);
 }
 
-static void do_snap(commands_t *cmd, client_info_t *client_info) {
-  create_snapshot(gGui->mmk.mrl, 
+static void do_snap(const commands_t *cmd, client_info_t *client_info) {
+  gGui_t *gui = gGui;
+  create_snapshot(gui->mmk.mrl, 
 		  network_messenger, network_messenger, (void *)(intptr_t)client_info->socket);
 }
 
@@ -2632,9 +2657,9 @@ static void parse_destock_remain(client_info_t *client_info) {
 	p++;
       
       if(p)
-	strcpy(remaining, (_atoa(p)));
+        strlcpy(remaining, (_atoa(p)), sizeof(remaining));
       
-      client_info->command.line = (char *) realloc(client_info->command.line, sizeof(char *) * (strlen(c) + 1));
+      client_info->command.line = (char *) realloc(client_info->command.line, sizeof(char) * (strlen(c) + 1));
       
       strcpy(client_info->command.line, c);
       
@@ -2650,7 +2675,7 @@ static void parse_destock_remain(client_info_t *client_info) {
 	
 	if(strlen(remaining)) {
 	  client_info->command.remain = (char *) realloc(client_info->command.remain, 
-							 sizeof(char *) * (strlen(remaining) + 1));
+							 sizeof(char) * (strlen(remaining) + 1));
 	  strcpy(client_info->command.remain, remaining);
 	}
 	else {
@@ -2665,7 +2690,7 @@ static void parse_destock_remain(client_info_t *client_info) {
     }
     else { /* no ';' in remain, copy AS IS remain to line */
       client_info->command.line = (char *) realloc(client_info->command.line, 
-						   sizeof(char *) * (strlen(client_info->command.remain) + 1));
+						   sizeof(char) * (strlen(client_info->command.remain) + 1));
       
       strcpy(client_info->command.line, client_info->command.remain);
       
@@ -2866,7 +2891,7 @@ static __attribute__((noreturn)) void *client_thread(void *data) {
   client_info_t     *client_info = (client_info_t *) data;
   char               buffer[_BUFSIZ];
   int                i;
-  int                len;
+  ssize_t            len;
   sigset_t           sigpipe_mask;
   
   pthread_detach(pthread_self());
@@ -2915,15 +2940,16 @@ static __attribute__((noreturn)) void *client_thread(void *data) {
  *
  */
 static __attribute__((noreturn)) void *server_thread(void *data) {
+  gGui_t *gui = gGui;
   char            *service;
   struct servent  *serv_ent;
   int              msock;
   
-  if(gGui->network_port) {
-    int len = (int) log10(gGui->network_port) + 1;
+  if(gui->network_port) {
+    int len = (int) log10(gui->network_port) + 1;
 
     service = (char *) malloc(len + 1);
-    sprintf(service, "%u", gGui->network_port);
+    sprintf(service, "%u", gui->network_port);
   } 
   else {
     /*  Search in /etc/services if a xinectl entry exist */
@@ -2961,7 +2987,7 @@ static __attribute__((noreturn)) void *server_thread(void *data) {
    *
    */
   {
-    char        *passwdfile = ".xine/passwd";
+    const char  *passwdfile = ".xine/passwd";
     char         passwdfilename[(strlen((xine_get_homedir())) + strlen(passwdfile)) + 2];
     struct stat  st;
     
@@ -2979,19 +3005,24 @@ static __attribute__((noreturn)) void *server_thread(void *data) {
 
   }
 
-  while(gGui->running) {
+  while(gui->running) {
     client_info_t       *client_info;
     socklen_t            lsin;
     pthread_t            thread_client;
     
     msock = sock_serv(service, "tcp", 5);
-    
+    if (msock < 0) {
+      break;
+    }
+
     client_info = (client_info_t *) calloc(1, sizeof(client_info_t));
     lsin = sizeof(client_info->fsin.in);
     
     client_info->socket = accept(msock, &(client_info->fsin.sa), &lsin);
     client_info->authentified = is_client_authorized(client_info);
     
+    close(msock);
+
     if(client_info->socket < 0) {
       
       free(client_info);
@@ -3003,8 +3034,6 @@ static __attribute__((noreturn)) void *server_thread(void *data) {
       continue;
     }
     
-    close(msock);
-
     pthread_create(&thread_client, NULL, client_thread, (void *)client_info);
   }
 
@@ -3030,9 +3059,10 @@ static __attribute__((noreturn)) void *server_thread(void *data) {
  *
  */
 void start_remote_server(void) {
+  gGui_t *gui = gGui;
   pthread_t thread;
 
-  if(gGui->network)
+  if(gui->network)
     pthread_create(&thread, NULL, server_thread, NULL);
   
 }
