@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2009 the xine project
+ * Copyright (C) 2000-2017 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -36,17 +36,20 @@
 #define OVL_PALETTE_SIZE 256
 
 #ifdef	__GNUC__
-#define CLUT_Y_CR_CB_INIT(_y,_cr,_cb)	{ .y = (_y), .cr = (_cr), .cb = (_cb)}
+#define CLUT_Y_CR_CB_INIT(_y,_cr,_cb)	{{ .y = (_y), .cr = (_cr), .cb = (_cb)}}
 #else
-#define CLUT_Y_CR_CB_INIT(_y,_cr,_cb)	{ (_cb), (_cr), (_y) }
+#define CLUT_Y_CR_CB_INIT(_y,_cr,_cb)	{{ (_cb), (_cr), (_y) }}
 #endif
 
-static const struct {         /* CLUT == Color LookUp Table */
-  uint8_t cb    : 8;
-  uint8_t cr    : 8;
-  uint8_t y     : 8;
-  uint8_t foo   : 8;
-} __attribute__ ((packed)) textpalettes_color[] = {
+static const union {         /* CLUT == Color LookUp Table */
+  struct {
+    uint8_t cb    : 8;
+    uint8_t cr    : 8;
+    uint8_t y     : 8;
+    uint8_t foo   : 8;
+  } u8;
+  uint32_t u32;
+} __attribute__ ((packed)) textpalettes_color[OVL_PALETTE_SIZE] = {
   /* white, no border, translucid */
     CLUT_Y_CR_CB_INIT(0x00, 0x00, 0x00), //0
     CLUT_Y_CR_CB_INIT(0x60, 0x80, 0x80), //1
@@ -73,7 +76,7 @@ static const struct {         /* CLUT == Color LookUp Table */
     CLUT_Y_CR_CB_INIT(0xff, 0x90, 0x00), //10
 };
 
-static const uint8_t textpalettes_trans[] = {
+static const uint8_t textpalettes_trans[OVL_PALETTE_SIZE] = {
   /* white, no border, translucid */
   0, 8, 9, 10, 11, 12, 13, 14, 15, 15, 15,
   /* yellow, black border, transparent */
@@ -156,7 +159,7 @@ void osd_init(void) {
 
   gGui->osd.bar.osd[0] = xine_osd_new(gGui->stream, 0, 0, BAR_WIDTH + 1, BAR_HEIGHT + 1);
   
-  xine_osd_set_palette(gGui->osd.bar.osd[0], textpalettes_color, textpalettes_trans);
+  xine_osd_set_palette(gGui->osd.bar.osd[0], &textpalettes_color[0].u32, textpalettes_trans);
 
   gGui->osd.bar.osd[1] = xine_osd_new(gGui->stream, 0, 0, BAR_WIDTH + 1, BAR_HEIGHT + 1);
   xine_osd_set_font(gGui->osd.bar.osd[1], "sans", fonth);
@@ -437,7 +440,7 @@ void osd_stream_infos(void) {
   }
 }
 
-void osd_draw_bar(char *title, int min, int max, int val, int type) {
+void osd_draw_bar(const char *title, int min, int max, int val, int type) {
 
   if(gGui->osd.enabled) {
     int      wwidth, wheight;
@@ -558,33 +561,18 @@ void osd_stream_position(int pos) {
   osd_draw_bar(_("Position in Stream"), 0, 65535, pos, OSD_BAR_POS2);
 }
 
-void osd_display_info(char *info, ...) {
+void osd_display_info(const char *info, ...) {
 
   if(gGui->osd.enabled && !gGui->on_quit) {
     va_list   args;
     char     *buf;
-    int       n, size = 100;
-    
-    if((buf = malloc(size)) == NULL) 
+
+    va_start(args, info);
+    buf = xitk_vasprintf(info, args);
+    va_end(args);
+
+    if (!buf)
       return;
-    
-    while(1) {
-      
-      va_start(args, info);
-      n = vsnprintf(buf, size, info, args);
-      va_end(args);
-      
-      if(n > -1 && n < size)
-	break;
-      
-      if(n > -1)
-	size = n + 1;
-      else
-	size *= 2;
-      
-      if((buf = realloc(buf, size)) == NULL)
-	return;
-    }
 
     xine_osd_clear(gGui->osd.info.osd[0]);
 
@@ -596,7 +584,7 @@ void osd_display_info(char *info, ...) {
     gGui->osd.info.visible = gGui->osd.timeout;
     pthread_mutex_unlock(&osd_mutex);
 
-    SAFE_FREE(buf);
+    free(buf);
   }
 }
 
@@ -683,8 +671,8 @@ void osd_update_status(void) {
 void osd_display_spu_lang(void) {
   char   buffer[XINE_LANG_MAX+128];
   char   lang_buffer[XINE_LANG_MAX];
-  char  *lang = NULL;
   int    channel;
+  const char *lang = NULL;
   
   channel = xine_get_param(gGui->stream, XINE_PARAM_SPU_CHANNEL);
 
@@ -712,8 +700,8 @@ void osd_display_spu_lang(void) {
 void osd_display_audio_lang(void) {
   char   buffer[XINE_LANG_MAX+128];
   char   lang_buffer[XINE_LANG_MAX];
-  char  *lang = NULL;
   int    channel;
+  const char *lang = NULL;
 
   channel = xine_get_param(gGui->stream, XINE_PARAM_AUDIO_CHANNEL_LOGICAL);
 
