@@ -50,10 +50,10 @@ void osd_display_audio_lang(void);
 void osd_stream_infos(void);
 void osd_update_status(void);
 void osd_stream_position(int pos);
-void osd_display_info(char *info, ...) __attribute__ ((format (printf, 1, 2)));
+void osd_display_info(const char *info, ...) __attribute__ ((format (printf, 1, 2)));
 
 /* see OSD_BAR_* */
-void osd_draw_bar(char *title, int min, int max, int val, int type);
+void osd_draw_bar(const char *title, int min, int max, int val, int type);
 
 void osd_update_osd(void);
 
