@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2002-2008 Stefan Holst
+ * Copyright (C) 2005-2017 the xine project
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -169,7 +170,8 @@ static void media_info_cb(void *data) {
   oxine_t *oxine = (oxine_t*) data;
   int pos_time, length, ret;
   int cline = 0;
-  char *buf1, *buf2;
+  const char *buf1;
+  char *buf2;
   /* otk_widget_t *b, *layout; */
 
   oxine->media_info_close_cb = media_info_close_cb;
@@ -651,7 +653,7 @@ static void return_cb(void *this) {
   return;
 }
 
-static void oxine_error_msg(char *text)
+static void oxine_error_msg(const char *text)
 {
   oxine_t *oxine = oxine_instance_get();
   otk_widget_t *b;
@@ -714,9 +716,10 @@ static oxine_t *create_oxine(void) {
 				NULL,
 				NULL);
  
-  xine_config_lookup_entry (oxine->xine, "input.dvd_device", &centry);
-  oxine->cd_device = centry.str_value;
-  
+  if (xine_config_lookup_entry (oxine->xine, "input.dvd_device", &centry)) {
+    oxine->cd_device = centry.str_value;
+  }
+
   start_scheduler();
   
   oxine->odk = odk_init();
