@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2013 the xine project
+ * Copyright (C) 2000-2017 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -29,6 +29,7 @@
 #include <string.h>
 #include <pthread.h>
 
+#define PANEL_PRIVATE
 #include "common.h"
 
 
@@ -212,10 +213,9 @@ void panel_change_skins(int synthetic) {
   old_img = panel->bg_image;
   panel->bg_image = new_img;
 
-  XLockDisplay(gGui->display);
+  video_window_set_transient_for (gGui->panel_window);
 
-  if(!gGui->use_root_window && gGui->video_display == gGui->display)
-    XSetTransientForHint(gGui->display, gGui->panel_window, gGui->video_window);
+  XLockDisplay(gGui->display);
 
   Imlib_destroy_image(gGui->imlib_data, old_img);
   Imlib_apply_image(gGui->imlib_data, new_img, gGui->panel_window);
@@ -288,9 +288,42 @@ void panel_change_skins(int synthetic) {
 /*
  * Update runtime displayed informations.
  */
+static void secs2str (char *s, unsigned int secs) {
+  /* Avoid slow snprintf (). Yes this does not support south asian */
+  /* alternative digits, but neither does the widget bitmap font.  */
+  /* But wait -- what if you modify letters.png now ?              */
+  if (secs >= 24 * 60 * 60) { /* [  dd::hh] */
+    unsigned int days;
+    secs /= 3600u;
+    days = secs / 24u;
+    secs %= 24u;
+    memcpy (s, "    ::  ", 8);
+    s[8] = 0;
+    s[7] = (secs % 10u) + '0';
+    s[6] = (secs / 10u) + '0';
+    s[3] = (days % 10u) + '0';
+    days /= 10u;
+    if (days)
+      s[2] = days + '0';
+  } else { /* [hh:mm:ss] */
+    s[8] = 0;
+    s[7] = (secs % 10u) + '0';
+    secs /= 10u;
+    s[6] = (secs % 6u) + '0';
+    secs /= 6u;
+    s[5] = ':';
+    s[4] = (secs % 10u) + '0';
+    secs /= 10u;
+    s[3] = (secs % 6u) + '0';
+    secs /= 6u;
+    s[2] = ':';
+    s[1] = (secs % 10u) + '0';
+    s[0] = (secs / 10u) + '0';
+  }
+}
 void panel_update_runtime_display(void) {
-  int seconds, pos, length, remain;
-  char timestr[10], buffer[256];
+  int seconds, pos, length;
+  char timestr[16];
 
   if(!panel_is_visible())
     return;
@@ -307,51 +340,58 @@ void panel_update_runtime_display(void) {
 
   }
 
-  if(pos || seconds) {
-    int days, rdays;
-    
-    remain  = (length - seconds) / 1000;
-    seconds /= 1000;
-    days    = seconds / (60*60*24);
-    rdays   = remain / (60*60*24);
-
-    if(panel->runtime_mode == 0) {
-      if(days > 0)
-	snprintf(timestr, sizeof(timestr), "% 4d::%02d", days, seconds / (60*60));
-      else
-	snprintf(timestr, sizeof(timestr), "%02d:%02d:%02d", seconds / (60*60), (seconds / 60) % 60, seconds % 60);
+  do {
+    unsigned int msecs = seconds, secs;
+    if (!(pos || msecs)) { /* are you sure there is something to play? */
+      panel->shown_time = ~3;
+      strcpy (timestr, "--:--:--");
+      break;
     }
-    else
-      if(remain < 0)
-	strcpy(timestr, "  :  :  ");
-      else {
-	if(rdays > 0)
-	  snprintf(timestr, sizeof(timestr), "% 4d::%02d", rdays, remain / (60*60));
-	else
-	  snprintf(timestr, sizeof(timestr), "%02d:%02d:%02d", remain / (60*60), (remain / 60) % 60, remain % 60);
+    if (panel->runtime_mode) { /* show remaining time */
+      if (msecs > (unsigned int)length) {
+        panel->shown_time = ~3;
+        strcpy (timestr, "  :  :  ");
+        break;
       }
-    
-  }
-  else
-    strcpy(timestr, "--:--:--");
+      msecs = length - msecs;
+    }
+    if (msecs == panel->shown_time) {
+      timestr[0] = 0;
+      break;
+    }
+    panel->shown_time = msecs;
+    secs   = msecs / 1000u;
+    msecs %= 1000u;
+    secs2str (timestr, secs);
+    if (xine_get_param (gGui->stream, XINE_PARAM_SPEED) > XINE_SPEED_NORMAL / 2)
+      break;
+    /* millisecond information is useful when editing. since we only update */
+    /* twice a second, show this in slow mode only. */
+    timestr[12] = 0;
+    timestr[11] = (msecs % 10u) + '0';
+    msecs /= 10u;
+    timestr[10] = (msecs % 10u) + '0';
+    timestr[9] = (msecs / 10u) + '0';
+    timestr[8] = '.';
+  } while (0);
   
-  if(length > 0) {
-    int days;
-
-    length /= 1000;
-    days = length / (60*60*24);
-    
-    if(days > 0)
-      snprintf(buffer, sizeof(buffer), "%s% 4d::%02d", _("Total time: "), days, length / (60*60));
+  if ((unsigned int)length != panel->shown_length) {
+    char buffer[256];
+    const char *ts = _("Total time: ");
+    size_t tl = strlen (ts);
+    if (tl > sizeof (buffer) - 9)
+      tl = sizeof (buffer) - 9;
+    memcpy (buffer, ts, tl);
+    panel->shown_length = length;
+    if (length > 0)
+      secs2str (buffer + tl, length / 1000);
     else
-      snprintf(buffer, sizeof(buffer), "%s%02d:%02d:%02d", _("Total time: "), length / (60*60), (length / 60) % 60, length % 60);
+      strcpy (buffer + tl, "??:??:??");
+    xitk_set_widget_tips (panel->runtime_label, buffer);
   }
-  else
-    snprintf(buffer, sizeof(buffer), "%s%s", _("Total time: "), "??:??:??");
-  
-  xitk_set_widget_tips(panel->runtime_label, buffer);
-  
-  xitk_label_change_label(panel->runtime_label, timestr); 
+
+  if (timestr[0])
+    xitk_label_change_label (panel->runtime_label, timestr);
 }
 
 /*
@@ -359,28 +399,26 @@ void panel_update_runtime_display(void) {
  */
 static __attribute__((noreturn)) void *slider_loop(void *dummy) {
   int screensaver_timer = 0;
-  int status, speed;
-  int pos, secs;
+  int lastmsecs = -1;
   int i = 0;
   
   while(gGui->on_quit == 0) {
 
     if(gGui->stream) {
       
-      status = xine_get_status(gGui->stream);
-      speed = xine_get_param(gGui->stream, XINE_PARAM_SPEED);
+      int status = xine_get_status (gGui->stream);
+      int speed  = xine_get_param (gGui->stream, XINE_PARAM_SPEED);
       
-      pos = 0;
+      int pos = 0, msecs = 0;
 
       if(status == XINE_STATUS_PLAY) {
-	if(gui_xine_get_pos_length(gGui->stream, &pos, &secs, NULL)) {
-	  secs /= 1000;
+        if (gui_xine_get_pos_length (gGui->stream, &pos, &msecs, NULL)) {
 
 	  pthread_mutex_lock(&gGui->xe_mutex);
 
 	  if(gGui->playlist.num && gGui->playlist.cur >= 0 && gGui->playlist.mmk &&
 	     gGui->playlist.mmk[gGui->playlist.cur] && gGui->mmk.end != -1) {
-	    if(secs >= gGui->playlist.mmk[gGui->playlist.cur]->end) {
+            if ((msecs / 1000) >= gGui->playlist.mmk[gGui->playlist.cur]->end) {
 	      gGui->ignore_next = 0;
 	      gui_playlist_start_next();
 	      pthread_mutex_unlock(&gGui->xe_mutex);
@@ -418,7 +456,8 @@ static __attribute__((noreturn)) void *slider_loop(void *dummy) {
 	}
       }
       
-      if((status == XINE_STATUS_PLAY) && (speed != XINE_SPEED_PAUSE)) {
+      if ((status == XINE_STATUS_PLAY) &&
+        ((speed != XINE_SPEED_PAUSE) || (msecs != lastmsecs))) {
 	char *ident = stream_infos_get_ident_from_stream(gGui->stream);
 	
 	if(ident) {
@@ -441,19 +480,20 @@ static __attribute__((noreturn)) void *slider_loop(void *dummy) {
 	else
 	  video_window_set_mrl((char *)gGui->mmk.mrl);
 	
-	if(!xitk_is_window_iconified(gGui->video_display, gGui->video_window)) {
-	  
-	  if(gGui->ssaver_timeout) {
-	    
-	    if(!(i % 2))
-	      screensaver_timer++;
-	    
-	    if(screensaver_timer >= gGui->ssaver_timeout) {
-	      screensaver_timer = video_window_reset_ssaver();
-	      
-	    }
-	  }  
-	}
+        {
+          int iconified;
+          video_window_lock (1);
+          iconified = xitk_is_window_iconified (gGui->video_display, gGui->video_window);
+          video_window_lock (0);
+          if (!iconified) {
+            if (gGui->ssaver_timeout) {
+              if (!(i % 2))
+                screensaver_timer++;
+              if (screensaver_timer >= gGui->ssaver_timeout)
+                screensaver_timer = video_window_reset_ssaver ();
+            }
+          }
+        }
 
 	if(gGui->logo_mode == 0) {
 	  
@@ -494,6 +534,7 @@ static __attribute__((noreturn)) void *slider_loop(void *dummy) {
 
 	}
       }
+      lastmsecs = msecs;
     }
     
     if(gGui->cursor_visible) {
@@ -600,15 +641,41 @@ static void _panel_toggle_visibility (xitk_widget_t *w, void *data) {
       else
 	XMapWindow(gGui->display, gGui->panel_window);
     }
-    
-    if(gGui->cursor_grabbed)
-      XGrabPointer(gGui->video_display, gGui->video_window, 1, None, GrabModeAsync, GrabModeAsync, gGui->video_window, None, CurrentTime);
-    
-    /* Give focus to video output window */
-    try_to_set_input_focus(gGui->video_window);
-    
+
     XUnlockDisplay(gGui->display);
-     
+
+    {
+      Window want;
+      int t;
+      video_window_lock (1);
+      want = gGui->video_window;
+      XLockDisplay (gGui->video_display);
+      if (gGui->cursor_grabbed)
+        XGrabPointer (gGui->video_display, want,
+          1, None, GrabModeAsync, GrabModeAsync, want, None, CurrentTime);
+      if (video_window_is_visible ()) {
+        /* Give focus to video output window */
+        XSetInputFocus (gGui->video_display, want, RevertToParent, CurrentTime);
+        XSync (gGui->video_display, False);
+        XUnlockDisplay (gGui->video_display);
+        video_window_lock (0);
+        /* check after 5/15/30/50/75/105/140 ms */
+        for (t = 5000; t < 40000; t += 5000) {
+          Window got;
+          int revert;
+          xine_usec_sleep (t);
+          XLockDisplay (gGui->video_display);
+          XGetInputFocus (gGui->video_display, &got, &revert);
+          XUnlockDisplay (gGui->video_display);
+          if (got == want)
+            break;
+        }
+      } else {
+        XUnlockDisplay (gGui->video_display);
+        video_window_lock (0);
+      }
+    }
+
   }
   else {
 
@@ -620,9 +687,8 @@ static void _panel_toggle_visibility (xitk_widget_t *w, void *data) {
     
     XRaiseWindow(gGui->display, gGui->panel_window); 
     XMapWindow(gGui->display, gGui->panel_window); 
-    if(!gGui->use_root_window && gGui->video_display == gGui->display)
-      XSetTransientForHint (gGui->display, gGui->panel_window, gGui->video_window);
     XUnlockDisplay (gGui->display);
+    video_window_set_transient_for (gGui->panel_window);
 
     wait_for_window_visible(gGui->display, gGui->panel_window);
     layer_above_video(gGui->panel_window);
@@ -1096,6 +1162,9 @@ void panel_init (void) {
 
   panel = (_panel_t *) calloc(1, sizeof(_panel_t));
 
+  panel->shown_length = ~3;
+  panel->shown_time = ~3;
+
   panel->playback_widgets.enabled = -1;
 
   panel->skin_on_change = 0;
@@ -1202,7 +1271,8 @@ void panel_init (void) {
   /*
    * wm, no border please
    */
-  
+
+  memset(&mwmhints, 0, sizeof(mwmhints));
   XLockDisplay(gGui->display);
   prop = XInternAtom(gGui->display, "_MOTIF_WM_HINTS", False);
   mwmhints.flags = MWM_HINTS_DECORATIONS;
@@ -1212,8 +1282,9 @@ void panel_init (void) {
                   PropModeReplace, (unsigned char *) &mwmhints,
                   PROP_MWM_HINTS_ELEMENTS);
   
-  if(!gGui->use_root_window && gGui->video_display == gGui->display)
-    XSetTransientForHint (gGui->display, gGui->panel_window, gGui->video_window);
+  XUnlockDisplay (gGui->display);
+  video_window_set_transient_for (gGui->panel_window);
+  XLockDisplay (gGui->display);
 
   /* 
    * set wm properties 
