@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2011 the xine project
+ * Copyright (C) 2000-2014 the xine project
  * 
  * This file is part of xine, a unix video player.
  * 
@@ -51,14 +51,14 @@ static int           going;
 static pthread_t     thread_server;
 static char         *socket_name;
 
-static void ssend_packet(int fd, void *data, uint32_t data_length) {
+static int ssend_packet(int fd, const void *data, uint32_t data_length) {
   ctrl_header_packet_t  hdr;
   
   hdr.version     = CTRL_PROTO_VERSION;
   hdr.command     = 0;
   hdr.data_length = data_length;
   
-  _send_packet(fd, data, &hdr);
+  return _send_packet(fd, data, &hdr);
 }
 
 static void send_ack(serv_header_packet_t *shdr) {
@@ -66,17 +66,20 @@ static void send_ack(serv_header_packet_t *shdr) {
   close(shdr->fd);
 }
 
-void send_uint32(int session, ctrl_commands_t command, uint32_t value) {
+static int send_uint32(int session, ctrl_commands_t command, uint32_t value) {
   int fd;
   
   if((fd = connect_to_session(session)) == -1)
-    return;
-  send_packet(fd, command, &value, sizeof(uint32_t));
-  read_ack(fd);
+    return -1;
+  if (send_packet(fd, command, &value, sizeof(uint32_t)) >= 0) {
+    read_ack(fd);
+  }
   close(fd);
+
+  return 0;
 }
 
-uint32_t get_uint32(int session, ctrl_commands_t command) {
+static uint32_t get_uint32(int session, ctrl_commands_t command) {
   ctrl_header_packet_t  hdr;
   void                 *data;
   int                   fd, ret = 0;
@@ -84,7 +87,10 @@ uint32_t get_uint32(int session, ctrl_commands_t command) {
   if((fd = connect_to_session(session)) == -1)
     return ret;
   
-  send_packet(fd, command, NULL, 0);
+  if (send_packet(fd, command, NULL, 0) < 0) {
+    close(fd);
+    return 0;
+  }
   data = read_packet(fd, &hdr);
   if(data) {
     ret = *((uint32_t *) data);
@@ -145,6 +151,7 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
     xine_usec_sleep(10000);
   
   while(going) {
+    int res;
 
     FD_ZERO(&set);
     FD_SET(ctrl_fd, &set);
@@ -153,9 +160,19 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
     tv.tv_usec = 100000;
 
     len = sizeof(saddr.un);
-    
-    if(((select(ctrl_fd + 1, &set, NULL, NULL, &tv)) <= 0) || 
-       ((fd = accept(ctrl_fd, &saddr.sa, &len)) == -1))
+
+    res = select(ctrl_fd + 1, &set, NULL, NULL, &tv);
+    if (res == 0)
+      continue;
+    if (res < 0) {
+      if (errno == EINTR || errno == EAGAIN)
+        continue;
+      fprintf(stderr, "ctrlsocket_func(): select failed: %s (%d)\n", strerror(errno), errno);
+      break;
+    }
+
+    fd = accept(ctrl_fd, &saddr.sa, &len);
+    if (fd < 0)
       continue;
 
     if (fcntl(fd, F_SETFD, FD_CLOEXEC) < 0) {
@@ -163,12 +180,25 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
     }
 
     shdr = (serv_header_packet_t *) calloc(1, sizeof(serv_header_packet_t));
+    if (!shdr) {
+      close(fd);
+      continue;
+    }
+
+    if (read(fd, &(shdr->hdr), sizeof(ctrl_header_packet_t)) != (ssize_t)sizeof(ctrl_header_packet_t)) {
+      SAFE_FREE(shdr);
+      close(fd);
+      continue;
+    }
 
-    (void) read(fd, &(shdr->hdr), sizeof(ctrl_header_packet_t));
-    
     if(shdr->hdr.data_length) {
       shdr->data = malloc(shdr->hdr.data_length);
-      read(fd, shdr->data, shdr->hdr.data_length);
+      if (read(fd, shdr->data, shdr->hdr.data_length) != (ssize_t)shdr->hdr.data_length) {
+        SAFE_FREE(shdr->data);
+        SAFE_FREE(shdr);
+        close(fd);
+        continue;
+      }
     }
 
     shdr->fd = fd;
@@ -418,6 +448,10 @@ static __attribute__((noreturn)) void *ctrlsocket_func(void *data) {
       send_ack(shdr);
       break;
 
+    default:
+      fprintf(stderr, "session: unknown command %d\n", shdr->hdr.command);
+      close(shdr->fd);
+      break;
     }
 
     SAFE_FREE(shdr->data);
@@ -493,17 +527,18 @@ int init_session(void) {
   return retval;
 }
 
-static int sanestrcasecmp(char *s1, char *s2) {
+static int sanestrcasecmp(const char *s1, const char *s2) {
   if(s1 && s2)
     return strcasecmp(s1, s2);
   return 1;
 } 
 
-int session_handle_subopt(char *suboptarg, char *enqueue_mrl, int *session) {
+int session_handle_subopt(char *suboptarg, const char *enqueue_mrl, int *session) {
   int          playlist_first, playlist_last, playlist_clear, playlist_next, playlist_prev, playlist_stop_cont;
   int          audio_next, audio_prev, spu_next, spu_prev;
   int          volume, amp, loop, speed_status, time_status;
   int          s, c;
+  int          i;
   uint32_t     state;
   char        *optstr;
   char       **mrls          = NULL;
@@ -673,15 +708,8 @@ int session_handle_subopt(char *suboptarg, char *enqueue_mrl, int *session) {
       remote_cmd(*session, CMD_PLAYLIST_CONTINUE);
 
     if(num_mrls) {
-      int i;
-
       for(i = 0; i < num_mrls; i++)
 	send_string(*session, CMD_PLAYLIST_ADD, mrls[i]);
-
-      for(i = 0; i < num_mrls; i++)
-	free(mrls[i]);
-      
-      free(mrls);
     }
     
     /* 
@@ -751,5 +779,10 @@ int session_handle_subopt(char *suboptarg, char *enqueue_mrl, int *session) {
   else
     fprintf(stderr, _("Session %d isn't running.\n"), *session);
 
+  for(i = 0; i < num_mrls; i++)
+    free(mrls[i]);
+
+  free(mrls);
+
   return retval;
 }
