@@ -59,6 +59,7 @@ typedef struct {
   pthread_mutex_t          mutex;      /* protecting mutex */
   xitk_font_cache_item_t   items[XITK_CACHE_SIZE]; /* cache */
 
+  pthread_mutex_t          xr_mutex;   /* protecting mutex */
   xitk_recode_t           *xr;         /* text recoding */
 } xitk_font_cache_t;
 
@@ -95,8 +96,7 @@ static int xitk_font_guess_error(XFontSet fs, char *name, char **missing, int co
 
 #ifdef WITH_XFT
 /* convert a -*-* .. style font description into something Xft can digest */
-static char * xitk_font_core_string_to_xft( char * old_name) {
-  static char new_name[255];
+static const char * xitk_font_core_string_to_xft(char *new_name, size_t new_name_size, const char * old_name) {
 
   if(old_name[0] == '-' || old_name[0] == '*') {
     char  family[50], weight[15], slant[8], pxsize[5], ptsize[5];
@@ -139,7 +139,7 @@ static char * xitk_font_core_string_to_xft( char * old_name) {
     }
     
     /* Build Xft font description string from the elements */
-    snprintf(new_name, sizeof(new_name), "%s%s%s%s%s%s%s%s%s",
+    snprintf(new_name, new_name_size, "%s%s%s%s%s%s%s%s%s",
 	     family,
 	     ((weight[0]) ? ":weight="    : ""), weight,
 	     ((slant[0])  ? ":slant="     : ""), slant,
@@ -204,9 +204,11 @@ static int xitk_font_load_one(Display *display, char *font, xitk_font_t *xtfs) {
 # endif
 #endif
   {
+    char new_name[255];
     XLOCK(display);
 #ifdef WITH_XFT
-    xtfs->font = XftFontOpenName( display, DefaultScreen(display), xitk_font_core_string_to_xft(font));
+    xtfs->font = XftFontOpenName( display, DefaultScreen(display),
+                                  xitk_font_core_string_to_xft(new_name, sizeof(new_name), font));
 #else
     xtfs->font = XLoadQueryFont(display, font);
 #endif
@@ -249,6 +251,7 @@ void xitk_font_cache_init(void) {
   cache.loaded = xitk_list_new();	
 
   pthread_mutex_init(&cache.mutex, NULL);
+  pthread_mutex_init(&cache.xr_mutex, NULL);
   
 #ifdef WITH_XFT
   cache.xr = xitk_recode_init(NULL, "UTF-8");
@@ -281,7 +284,7 @@ void xitk_font_cache_done(void) {
       XITK_WARNING("%s(): list of loaded font isn't empty:\n", __FUNCTION__);
       item = xitk_list_first_content(cache.loaded);
       while(item) {
-	printf("  %s (%d)\n", item->font->name, item->number);
+	printf("  %s (%u)\n", item->font->name, item->number);
 	item = xitk_list_next_content(cache.loaded);
       }
     }
@@ -290,6 +293,7 @@ void xitk_font_cache_done(void) {
 
   xitk_list_free(cache.loaded);
   pthread_mutex_destroy(&cache.mutex);
+  pthread_mutex_destroy(&cache.xr_mutex);
 
   xitk_recode_done(cache.xr);
 }
@@ -374,7 +378,7 @@ static void xitk_cache_add_item(xitk_font_t *font) {
     xtfs   = cache.items[oldest].font;
 
 #ifdef LOG
-    printf("xiTK: dropped \"%s\", list: %d, cache: %d\n", xtfs->name, cache.nlist, cache.n);
+    printf("xiTK: dropped \"%s\", list: %zu, cache: %zu\n", xtfs->name, cache.nlist, cache.n);
 #endif
 
     xitk_font_unload_one(xtfs);
@@ -490,6 +494,16 @@ static xitk_font_list_item_t *cache_get_from_list(Display *display, char *name)
   return NULL;
 }
 
+static char *xitk_cache_recode(const char *text)
+{
+  char *result;
+  pthread_mutex_lock(&cache.xr_mutex);
+  result = xitk_recode(cache.xr, text);
+  pthread_mutex_unlock(&cache.xr_mutex);
+  return result;
+}
+
+
 /*
  *
  */
@@ -545,7 +559,7 @@ xitk_font_t *xitk_font_load_font(Display *display, char *font) {
     xtfs->display = display;
 
 #ifdef LOG
-    printf("xiTK: loaded new \"%s\", list: %d, cache: %d\n", xtfs->name, cache.nlist, cache.n);
+    printf("xiTK: loaded new \"%s\", list: %zu, cache: %zu\n", xtfs->name, cache.nlist, cache.n);
 #endif
   }
 
@@ -603,7 +617,7 @@ void xitk_font_draw_string(xitk_font_t *xtfs, Pixmap pix, GC gc,
 
 #ifdef DEBUG
   if (nbytes > strlen(text) + 1) {
-    XITK_WARNING("draw: %d > %d\n", nbytes, strlen(text));
+    XITK_WARNING("draw: %zu > %zu\n", nbytes, strlen(text));
   }
 #endif
   
@@ -625,7 +639,7 @@ void xitk_font_draw_string(xitk_font_t *xtfs, Pixmap pix, GC gc,
     XRenderColor  xr_color;
     XftColor      xcolor;
     XftDraw      *xft_draw;
-    char         *encoded_text = xitk_recode(cache.xr, text);
+    char         *encoded_text = xitk_cache_recode(text);
 
     XGetGCValues(xtfs->display, gc, GCForeground, &gc_color);
     paint_color.pixel = gc_color.foreground;
@@ -885,7 +899,7 @@ void xitk_font_text_extent(xitk_font_t *xtfs, const char *c, int nbytes,
 
   foo_text = strdup(c);
   foo_text[nbytes] = '\0';
-  encoded_text = xitk_recode(cache.xr, foo_text);
+  encoded_text = xitk_cache_recode(foo_text);
   nbytes = strlen(encoded_text);
   free(foo_text);
   
